@@ -1,4 +1,6 @@
--- UUAGC 0.9.5 (AbstractSyntax.ag)
+
+
+-- UUAGC 0.9.14 (AbstractSyntax.ag)
 module AbstractSyntax where
 
 -- AbstractSyntax.ag imports
@@ -17,16 +19,16 @@ import CommonTypes
          child syn            : {Attributes}
          child higherOrder    : {Bool}
 -}
-data Child = Child (Identifier) (Type) (Attributes) (Attributes) (Bool)
+data Child  = Child (Identifier) (Type) (Attributes) (Attributes) (Bool) 
 -- Children ----------------------------------------------------
 {-
    alternatives:
       alternative Cons:
-         child hd             : Child
-         child tl             : Children
+         child hd             : Child 
+         child tl             : Children 
       alternative Nil:
 -}
-type Children = [Child]
+type Children  = [(Child)]
 -- Grammar -----------------------------------------------------
 {-
    alternatives:
@@ -35,13 +37,15 @@ type Children = [Child]
          child useMap         : {UseMap}
          child derivings      : {Derivings}
          child wrappers       : {Set NontermIdent}
-         child nonts          : Nonterminals
+         child nonts          : Nonterminals 
          child pragmas        : {PragmaMap}
          child manualAttrOrderMap : {AttrOrderMap}
          child paramMap       : {ParamMap}
          child contextMap     : {ContextMap}
+         child uniqueMap      : {UniqueMap}
+         child augmentsMap    : {Map NontermIdent (Map ConstructorIdent (Map Identifier [Expression]))}
 -}
-data Grammar = Grammar (TypeSyns) (UseMap) (Derivings) (Set NontermIdent) (Nonterminals) (PragmaMap) (AttrOrderMap) (ParamMap) (ContextMap)
+data Grammar  = Grammar (TypeSyns) (UseMap) (Derivings) (Set NontermIdent) (Nonterminals) (PragmaMap) (AttrOrderMap) (ParamMap) (ContextMap) (UniqueMap) (Map NontermIdent (Map ConstructorIdent (Map Identifier [Expression]))) 
 -- Nonterminal -------------------------------------------------
 {-
    alternatives:
@@ -50,37 +54,37 @@ data Grammar = Grammar (TypeSyns) (UseMap) (Derivings) (Set NontermIdent) (Nonte
          child params         : {[Identifier]}
          child inh            : {Attributes}
          child syn            : {Attributes}
-         child prods          : Productions
+         child prods          : Productions 
 -}
-data Nonterminal = Nonterminal (NontermIdent) ([Identifier]) (Attributes) (Attributes) (Productions)
+data Nonterminal  = Nonterminal (NontermIdent) ([Identifier]) (Attributes) (Attributes) (Productions) 
 -- Nonterminals ------------------------------------------------
 {-
    alternatives:
       alternative Cons:
-         child hd             : Nonterminal
-         child tl             : Nonterminals
+         child hd             : Nonterminal 
+         child tl             : Nonterminals 
       alternative Nil:
 -}
-type Nonterminals = [Nonterminal]
+type Nonterminals  = [(Nonterminal)]
 -- Production --------------------------------------------------
 {-
    alternatives:
       alternative Production:
          child con            : {ConstructorIdent}
-         child children       : Children
-         child rules          : Rules
-         child typeSigs       : TypeSigs
+         child children       : Children 
+         child rules          : Rules 
+         child typeSigs       : TypeSigs 
 -}
-data Production = Production (ConstructorIdent) (Children) (Rules) (TypeSigs)
+data Production  = Production (ConstructorIdent) (Children) (Rules) (TypeSigs) 
 -- Productions -------------------------------------------------
 {-
    alternatives:
       alternative Cons:
-         child hd             : Production
-         child tl             : Productions
+         child hd             : Production 
+         child tl             : Productions 
       alternative Nil:
 -}
-type Productions = [Production]
+type Productions  = [(Production)]
 -- Rule --------------------------------------------------------
 {-
    alternatives:
@@ -90,16 +94,16 @@ type Productions = [Production]
          child owrt           : {Bool}
          child origin         : {String}
 -}
-data Rule = Rule (Pattern) (Expression) (Bool) (String)
+data Rule  = Rule (Pattern) (Expression) (Bool) (String) 
 -- Rules -------------------------------------------------------
 {-
    alternatives:
       alternative Cons:
-         child hd             : Rule
-         child tl             : Rules
+         child hd             : Rule 
+         child tl             : Rules 
       alternative Nil:
 -}
-type Rules = [Rule]
+type Rules  = [(Rule)]
 -- TypeSig -----------------------------------------------------
 {-
    alternatives:
@@ -107,13 +111,13 @@ type Rules = [Rule]
          child name           : {Identifier}
          child tp             : {Type}
 -}
-data TypeSig = TypeSig (Identifier) (Type)
+data TypeSig  = TypeSig (Identifier) (Type) 
 -- TypeSigs ----------------------------------------------------
 {-
    alternatives:
       alternative Cons:
-         child hd             : TypeSig
-         child tl             : TypeSigs
+         child hd             : TypeSig 
+         child tl             : TypeSigs 
       alternative Nil:
 -}
-type TypeSigs = [TypeSig]
+type TypeSigs  = [(TypeSig)]
\ No newline at end of file
