@@ -1,4 +1,6 @@
--- UUAGC 0.9.5 (AbstractSyntaxDump.ag)
+
+
+-- UUAGC 0.9.14 (AbstractSyntaxDump.ag)
 module AbstractSyntaxDump where
 
 import Data.List
@@ -10,6 +12,7 @@ import PPUtil
 import AbstractSyntax
 import TokenDef
 
+
 -- AbstractSyntax.ag imports
 import Data.Set(Set)
 import Data.Map(Map)
@@ -17,10 +20,12 @@ import Patterns    (Pattern(..),Patterns)
 import Expression  (Expression(..))
 import CommonTypes
 
+
 -- Patterns.ag imports
 import UU.Scanner.Position(Pos)
 import CommonTypes (ConstructorIdent,Identifier)
 
+
 import UU.Scanner.Position(Pos)
 import HsToken
 -- Child -------------------------------------------------------
@@ -37,30 +42,33 @@ import HsToken
          child higherOrder    : {Bool}
 -}
 -- cata
-sem_Child :: Child ->
-             T_Child
-sem_Child (Child _name _tp _inh _syn _higherOrder) =
-    (sem_Child_Child _name _tp _inh _syn _higherOrder)
+sem_Child :: Child  ->
+             T_Child 
+sem_Child (Child _name _tp _inh _syn _higherOrder )  =
+    (sem_Child_Child _name _tp _inh _syn _higherOrder )
 -- semantic domain
-newtype T_Child = T_Child (( PP_Doc))
-data Inh_Child = Inh_Child {}
-data Syn_Child = Syn_Child {pp_Syn_Child :: PP_Doc}
-wrap_Child (T_Child sem) (Inh_Child ) =
+newtype T_Child  = T_Child (( PP_Doc))
+data Inh_Child  = Inh_Child {}
+data Syn_Child  = Syn_Child {pp_Syn_Child :: PP_Doc}
+wrap_Child :: T_Child  ->
+              Inh_Child  ->
+              Syn_Child 
+wrap_Child (T_Child sem ) (Inh_Child )  =
     (let ( _lhsOpp) =
              (sem )
-     in  (Syn_Child _lhsOpp))
+     in  (Syn_Child _lhsOpp ))
 sem_Child_Child :: Identifier ->
                    Type ->
                    Attributes ->
                    Attributes ->
                    Bool ->
-                   T_Child
-sem_Child_Child name_ tp_ inh_ syn_ higherOrder_ =
+                   T_Child 
+sem_Child_Child name_ tp_ inh_ syn_ higherOrder_  =
     (T_Child (let _lhsOpp :: PP_Doc
                   -- "AbstractSyntaxDump.ag"(line 35, column 33)
                   _lhsOpp =
                       ppNestInfo ["Child","Child"] [pp name_, ppShow tp_] [ppF "inh" $ ppMap inh_, ppF "syn" $ ppMap syn_] []
-              in  ( _lhsOpp)))
+              in  ( _lhsOpp)) )
 -- Children ----------------------------------------------------
 {-
    visit 0:
@@ -69,27 +77,30 @@ sem_Child_Child name_ tp_ inh_ syn_ higherOrder_ =
          ppL                  : [PP_Doc]
    alternatives:
       alternative Cons:
-         child hd             : Child
-         child tl             : Children
+         child hd             : Child 
+         child tl             : Children 
       alternative Nil:
 -}
 -- cata
-sem_Children :: Children ->
-                T_Children
-sem_Children list =
-    (Prelude.foldr sem_Children_Cons sem_Children_Nil (Prelude.map sem_Child list))
+sem_Children :: Children  ->
+                T_Children 
+sem_Children list  =
+    (Prelude.foldr sem_Children_Cons sem_Children_Nil (Prelude.map sem_Child list) )
 -- semantic domain
-newtype T_Children = T_Children (( PP_Doc,([PP_Doc])))
-data Inh_Children = Inh_Children {}
-data Syn_Children = Syn_Children {pp_Syn_Children :: PP_Doc,ppL_Syn_Children :: [PP_Doc]}
-wrap_Children (T_Children sem) (Inh_Children ) =
+newtype T_Children  = T_Children (( PP_Doc,([PP_Doc])))
+data Inh_Children  = Inh_Children {}
+data Syn_Children  = Syn_Children {pp_Syn_Children :: PP_Doc,ppL_Syn_Children :: [PP_Doc]}
+wrap_Children :: T_Children  ->
+                 Inh_Children  ->
+                 Syn_Children 
+wrap_Children (T_Children sem ) (Inh_Children )  =
     (let ( _lhsOpp,_lhsOppL) =
              (sem )
-     in  (Syn_Children _lhsOpp _lhsOppL))
-sem_Children_Cons :: T_Child ->
-                     T_Children ->
-                     T_Children
-sem_Children_Cons (T_Child hd_) (T_Children tl_) =
+     in  (Syn_Children _lhsOpp _lhsOppL ))
+sem_Children_Cons :: T_Child  ->
+                     T_Children  ->
+                     T_Children 
+sem_Children_Cons (T_Child hd_ ) (T_Children tl_ )  =
     (T_Children (let _lhsOppL :: ([PP_Doc])
                      _lhsOpp :: PP_Doc
                      _hdIpp :: PP_Doc
@@ -105,8 +116,8 @@ sem_Children_Cons (T_Child hd_) (T_Children tl_) =
                          (hd_ )
                      ( _tlIpp,_tlIppL) =
                          (tl_ )
-                 in  ( _lhsOpp,_lhsOppL)))
-sem_Children_Nil :: T_Children
+                 in  ( _lhsOpp,_lhsOppL)) )
+sem_Children_Nil :: T_Children 
 sem_Children_Nil  =
     (T_Children (let _lhsOppL :: ([PP_Doc])
                      _lhsOpp :: PP_Doc
@@ -116,7 +127,7 @@ sem_Children_Nil  =
                      -- use rule "AbstractSyntaxDump.ag"(line 17, column 58)
                      _lhsOpp =
                          empty
-                 in  ( _lhsOpp,_lhsOppL)))
+                 in  ( _lhsOpp,_lhsOppL)) )
 -- Expression --------------------------------------------------
 {-
    visit 0:
@@ -128,27 +139,30 @@ sem_Children_Nil  =
          child tks            : {[HsToken]}
 -}
 -- cata
-sem_Expression :: Expression ->
-                  T_Expression
-sem_Expression (Expression _pos _tks) =
-    (sem_Expression_Expression _pos _tks)
+sem_Expression :: Expression  ->
+                  T_Expression 
+sem_Expression (Expression _pos _tks )  =
+    (sem_Expression_Expression _pos _tks )
 -- semantic domain
-newtype T_Expression = T_Expression (( PP_Doc))
-data Inh_Expression = Inh_Expression {}
-data Syn_Expression = Syn_Expression {pp_Syn_Expression :: PP_Doc}
-wrap_Expression (T_Expression sem) (Inh_Expression ) =
+newtype T_Expression  = T_Expression (( PP_Doc))
+data Inh_Expression  = Inh_Expression {}
+data Syn_Expression  = Syn_Expression {pp_Syn_Expression :: PP_Doc}
+wrap_Expression :: T_Expression  ->
+                   Inh_Expression  ->
+                   Syn_Expression 
+wrap_Expression (T_Expression sem ) (Inh_Expression )  =
     (let ( _lhsOpp) =
              (sem )
-     in  (Syn_Expression _lhsOpp))
+     in  (Syn_Expression _lhsOpp ))
 sem_Expression_Expression :: Pos ->
                              ([HsToken]) ->
-                             T_Expression
-sem_Expression_Expression pos_ tks_ =
+                             T_Expression 
+sem_Expression_Expression pos_ tks_  =
     (T_Expression (let _lhsOpp :: PP_Doc
                        -- "AbstractSyntaxDump.ag"(line 50, column 25)
                        _lhsOpp =
                            ppNestInfo ["Expression","Expression"] [ppShow pos_] [ppF "txt" $ vlist . showTokens . tokensToStrings $ tks_] []
-                   in  ( _lhsOpp)))
+                   in  ( _lhsOpp)) )
 -- Grammar -----------------------------------------------------
 {-
    visit 0:
@@ -160,36 +174,43 @@ sem_Expression_Expression pos_ tks_ =
          child useMap         : {UseMap}
          child derivings      : {Derivings}
          child wrappers       : {Set NontermIdent}
-         child nonts          : Nonterminals
+         child nonts          : Nonterminals 
          child pragmas        : {PragmaMap}
          child manualAttrOrderMap : {AttrOrderMap}
          child paramMap       : {ParamMap}
          child contextMap     : {ContextMap}
+         child uniqueMap      : {UniqueMap}
+         child augmentsMap    : {Map NontermIdent (Map ConstructorIdent (Map Identifier [Expression]))}
 -}
 -- cata
-sem_Grammar :: Grammar ->
-               T_Grammar
-sem_Grammar (Grammar _typeSyns _useMap _derivings _wrappers _nonts _pragmas _manualAttrOrderMap _paramMap _contextMap) =
-    (sem_Grammar_Grammar _typeSyns _useMap _derivings _wrappers (sem_Nonterminals _nonts) _pragmas _manualAttrOrderMap _paramMap _contextMap)
+sem_Grammar :: Grammar  ->
+               T_Grammar 
+sem_Grammar (Grammar _typeSyns _useMap _derivings _wrappers _nonts _pragmas _manualAttrOrderMap _paramMap _contextMap _uniqueMap _augmentsMap )  =
+    (sem_Grammar_Grammar _typeSyns _useMap _derivings _wrappers (sem_Nonterminals _nonts ) _pragmas _manualAttrOrderMap _paramMap _contextMap _uniqueMap _augmentsMap )
 -- semantic domain
-newtype T_Grammar = T_Grammar (( PP_Doc))
-data Inh_Grammar = Inh_Grammar {}
-data Syn_Grammar = Syn_Grammar {pp_Syn_Grammar :: PP_Doc}
-wrap_Grammar (T_Grammar sem) (Inh_Grammar ) =
+newtype T_Grammar  = T_Grammar (( PP_Doc))
+data Inh_Grammar  = Inh_Grammar {}
+data Syn_Grammar  = Syn_Grammar {pp_Syn_Grammar :: PP_Doc}
+wrap_Grammar :: T_Grammar  ->
+                Inh_Grammar  ->
+                Syn_Grammar 
+wrap_Grammar (T_Grammar sem ) (Inh_Grammar )  =
     (let ( _lhsOpp) =
              (sem )
-     in  (Syn_Grammar _lhsOpp))
+     in  (Syn_Grammar _lhsOpp ))
 sem_Grammar_Grammar :: TypeSyns ->
                        UseMap ->
                        Derivings ->
                        (Set NontermIdent) ->
-                       T_Nonterminals ->
+                       T_Nonterminals  ->
                        PragmaMap ->
                        AttrOrderMap ->
                        ParamMap ->
                        ContextMap ->
-                       T_Grammar
-sem_Grammar_Grammar typeSyns_ useMap_ derivings_ wrappers_ (T_Nonterminals nonts_) pragmas_ manualAttrOrderMap_ paramMap_ contextMap_ =
+                       UniqueMap ->
+                       (Map NontermIdent (Map ConstructorIdent (Map Identifier [Expression]))) ->
+                       T_Grammar 
+sem_Grammar_Grammar typeSyns_ useMap_ derivings_ wrappers_ (T_Nonterminals nonts_ ) pragmas_ manualAttrOrderMap_ paramMap_ contextMap_ uniqueMap_ augmentsMap_  =
     (T_Grammar (let _lhsOpp :: PP_Doc
                     _nontsIpp :: PP_Doc
                     _nontsIppL :: ([PP_Doc])
@@ -204,7 +225,7 @@ sem_Grammar_Grammar typeSyns_ useMap_ derivings_ wrappers_ (T_Nonterminals nonts
                            ] []
                     ( _nontsIpp,_nontsIppL) =
                         (nonts_ )
-                in  ( _lhsOpp)))
+                in  ( _lhsOpp)) )
 -- Nonterminal -------------------------------------------------
 {-
    visit 0:
@@ -216,28 +237,31 @@ sem_Grammar_Grammar typeSyns_ useMap_ derivings_ wrappers_ (T_Nonterminals nonts
          child params         : {[Identifier]}
          child inh            : {Attributes}
          child syn            : {Attributes}
-         child prods          : Productions
+         child prods          : Productions 
 -}
 -- cata
-sem_Nonterminal :: Nonterminal ->
-                   T_Nonterminal
-sem_Nonterminal (Nonterminal _nt _params _inh _syn _prods) =
-    (sem_Nonterminal_Nonterminal _nt _params _inh _syn (sem_Productions _prods))
+sem_Nonterminal :: Nonterminal  ->
+                   T_Nonterminal 
+sem_Nonterminal (Nonterminal _nt _params _inh _syn _prods )  =
+    (sem_Nonterminal_Nonterminal _nt _params _inh _syn (sem_Productions _prods ) )
 -- semantic domain
-newtype T_Nonterminal = T_Nonterminal (( PP_Doc))
-data Inh_Nonterminal = Inh_Nonterminal {}
-data Syn_Nonterminal = Syn_Nonterminal {pp_Syn_Nonterminal :: PP_Doc}
-wrap_Nonterminal (T_Nonterminal sem) (Inh_Nonterminal ) =
+newtype T_Nonterminal  = T_Nonterminal (( PP_Doc))
+data Inh_Nonterminal  = Inh_Nonterminal {}
+data Syn_Nonterminal  = Syn_Nonterminal {pp_Syn_Nonterminal :: PP_Doc}
+wrap_Nonterminal :: T_Nonterminal  ->
+                    Inh_Nonterminal  ->
+                    Syn_Nonterminal 
+wrap_Nonterminal (T_Nonterminal sem ) (Inh_Nonterminal )  =
     (let ( _lhsOpp) =
              (sem )
-     in  (Syn_Nonterminal _lhsOpp))
+     in  (Syn_Nonterminal _lhsOpp ))
 sem_Nonterminal_Nonterminal :: NontermIdent ->
                                ([Identifier]) ->
                                Attributes ->
                                Attributes ->
-                               T_Productions ->
-                               T_Nonterminal
-sem_Nonterminal_Nonterminal nt_ params_ inh_ syn_ (T_Productions prods_) =
+                               T_Productions  ->
+                               T_Nonterminal 
+sem_Nonterminal_Nonterminal nt_ params_ inh_ syn_ (T_Productions prods_ )  =
     (T_Nonterminal (let _lhsOpp :: PP_Doc
                         _prodsIpp :: PP_Doc
                         _prodsIppL :: ([PP_Doc])
@@ -246,7 +270,7 @@ sem_Nonterminal_Nonterminal nt_ params_ inh_ syn_ (T_Productions prods_) =
                             ppNestInfo ["Nonterminal","Nonterminal"] (pp nt_ : map pp params_) [ppF "inh" $ ppMap inh_, ppF "syn" $ ppMap syn_, ppF "prods" $ ppVList _prodsIppL] []
                         ( _prodsIpp,_prodsIppL) =
                             (prods_ )
-                    in  ( _lhsOpp)))
+                    in  ( _lhsOpp)) )
 -- Nonterminals ------------------------------------------------
 {-
    visit 0:
@@ -255,27 +279,30 @@ sem_Nonterminal_Nonterminal nt_ params_ inh_ syn_ (T_Productions prods_) =
          ppL                  : [PP_Doc]
    alternatives:
       alternative Cons:
-         child hd             : Nonterminal
-         child tl             : Nonterminals
+         child hd             : Nonterminal 
+         child tl             : Nonterminals 
       alternative Nil:
 -}
 -- cata
-sem_Nonterminals :: Nonterminals ->
-                    T_Nonterminals
-sem_Nonterminals list =
-    (Prelude.foldr sem_Nonterminals_Cons sem_Nonterminals_Nil (Prelude.map sem_Nonterminal list))
+sem_Nonterminals :: Nonterminals  ->
+                    T_Nonterminals 
+sem_Nonterminals list  =
+    (Prelude.foldr sem_Nonterminals_Cons sem_Nonterminals_Nil (Prelude.map sem_Nonterminal list) )
 -- semantic domain
-newtype T_Nonterminals = T_Nonterminals (( PP_Doc,([PP_Doc])))
-data Inh_Nonterminals = Inh_Nonterminals {}
-data Syn_Nonterminals = Syn_Nonterminals {pp_Syn_Nonterminals :: PP_Doc,ppL_Syn_Nonterminals :: [PP_Doc]}
-wrap_Nonterminals (T_Nonterminals sem) (Inh_Nonterminals ) =
+newtype T_Nonterminals  = T_Nonterminals (( PP_Doc,([PP_Doc])))
+data Inh_Nonterminals  = Inh_Nonterminals {}
+data Syn_Nonterminals  = Syn_Nonterminals {pp_Syn_Nonterminals :: PP_Doc,ppL_Syn_Nonterminals :: [PP_Doc]}
+wrap_Nonterminals :: T_Nonterminals  ->
+                     Inh_Nonterminals  ->
+                     Syn_Nonterminals 
+wrap_Nonterminals (T_Nonterminals sem ) (Inh_Nonterminals )  =
     (let ( _lhsOpp,_lhsOppL) =
              (sem )
-     in  (Syn_Nonterminals _lhsOpp _lhsOppL))
-sem_Nonterminals_Cons :: T_Nonterminal ->
-                         T_Nonterminals ->
-                         T_Nonterminals
-sem_Nonterminals_Cons (T_Nonterminal hd_) (T_Nonterminals tl_) =
+     in  (Syn_Nonterminals _lhsOpp _lhsOppL ))
+sem_Nonterminals_Cons :: T_Nonterminal  ->
+                         T_Nonterminals  ->
+                         T_Nonterminals 
+sem_Nonterminals_Cons (T_Nonterminal hd_ ) (T_Nonterminals tl_ )  =
     (T_Nonterminals (let _lhsOppL :: ([PP_Doc])
                          _lhsOpp :: PP_Doc
                          _hdIpp :: PP_Doc
@@ -291,8 +318,8 @@ sem_Nonterminals_Cons (T_Nonterminal hd_) (T_Nonterminals tl_) =
                              (hd_ )
                          ( _tlIpp,_tlIppL) =
                              (tl_ )
-                     in  ( _lhsOpp,_lhsOppL)))
-sem_Nonterminals_Nil :: T_Nonterminals
+                     in  ( _lhsOpp,_lhsOppL)) )
+sem_Nonterminals_Nil :: T_Nonterminals 
 sem_Nonterminals_Nil  =
     (T_Nonterminals (let _lhsOppL :: ([PP_Doc])
                          _lhsOpp :: PP_Doc
@@ -302,33 +329,33 @@ sem_Nonterminals_Nil  =
                          -- use rule "AbstractSyntaxDump.ag"(line 17, column 58)
                          _lhsOpp =
                              empty
-                     in  ( _lhsOpp,_lhsOppL)))
+                     in  ( _lhsOpp,_lhsOppL)) )
 -- Pattern -----------------------------------------------------
 {-
    visit 0:
       synthesized attributes:
-         copy                 : SELF
+         copy                 : SELF 
          pp                   : PP_Doc
    alternatives:
       alternative Alias:
          child field          : {Identifier}
          child attr           : {Identifier}
-         child pat            : Pattern
-         child parts          : Patterns
+         child pat            : Pattern 
+         child parts          : Patterns 
          visit 0:
             local copy        : _
       alternative Constr:
          child name           : {ConstructorIdent}
-         child pats           : Patterns
+         child pats           : Patterns 
          visit 0:
             local copy        : _
       alternative Irrefutable:
-         child pat            : Pattern
+         child pat            : Pattern 
          visit 0:
             local copy        : _
       alternative Product:
          child pos            : {Pos}
-         child pats           : Patterns
+         child pats           : Patterns 
          visit 0:
             local copy        : _
       alternative Underscore:
@@ -337,32 +364,35 @@ sem_Nonterminals_Nil  =
             local copy        : _
 -}
 -- cata
-sem_Pattern :: Pattern ->
-               T_Pattern
-sem_Pattern (Alias _field _attr _pat _parts) =
-    (sem_Pattern_Alias _field _attr (sem_Pattern _pat) (sem_Patterns _parts))
-sem_Pattern (Constr _name _pats) =
-    (sem_Pattern_Constr _name (sem_Patterns _pats))
-sem_Pattern (Irrefutable _pat) =
-    (sem_Pattern_Irrefutable (sem_Pattern _pat))
-sem_Pattern (Product _pos _pats) =
-    (sem_Pattern_Product _pos (sem_Patterns _pats))
-sem_Pattern (Underscore _pos) =
-    (sem_Pattern_Underscore _pos)
+sem_Pattern :: Pattern  ->
+               T_Pattern 
+sem_Pattern (Alias _field _attr _pat _parts )  =
+    (sem_Pattern_Alias _field _attr (sem_Pattern _pat ) (sem_Patterns _parts ) )
+sem_Pattern (Constr _name _pats )  =
+    (sem_Pattern_Constr _name (sem_Patterns _pats ) )
+sem_Pattern (Irrefutable _pat )  =
+    (sem_Pattern_Irrefutable (sem_Pattern _pat ) )
+sem_Pattern (Product _pos _pats )  =
+    (sem_Pattern_Product _pos (sem_Patterns _pats ) )
+sem_Pattern (Underscore _pos )  =
+    (sem_Pattern_Underscore _pos )
 -- semantic domain
-newtype T_Pattern = T_Pattern (( Pattern,PP_Doc))
-data Inh_Pattern = Inh_Pattern {}
-data Syn_Pattern = Syn_Pattern {copy_Syn_Pattern :: Pattern,pp_Syn_Pattern :: PP_Doc}
-wrap_Pattern (T_Pattern sem) (Inh_Pattern ) =
+newtype T_Pattern  = T_Pattern (( Pattern,PP_Doc))
+data Inh_Pattern  = Inh_Pattern {}
+data Syn_Pattern  = Syn_Pattern {copy_Syn_Pattern :: Pattern,pp_Syn_Pattern :: PP_Doc}
+wrap_Pattern :: T_Pattern  ->
+                Inh_Pattern  ->
+                Syn_Pattern 
+wrap_Pattern (T_Pattern sem ) (Inh_Pattern )  =
     (let ( _lhsOcopy,_lhsOpp) =
              (sem )
-     in  (Syn_Pattern _lhsOcopy _lhsOpp))
+     in  (Syn_Pattern _lhsOcopy _lhsOpp ))
 sem_Pattern_Alias :: Identifier ->
                      Identifier ->
-                     T_Pattern ->
-                     T_Patterns ->
-                     T_Pattern
-sem_Pattern_Alias field_ attr_ (T_Pattern pat_) (T_Patterns parts_) =
+                     T_Pattern  ->
+                     T_Patterns  ->
+                     T_Pattern 
+sem_Pattern_Alias field_ attr_ (T_Pattern pat_ ) (T_Patterns parts_ )  =
     (T_Pattern (let _lhsOpp :: PP_Doc
                     _lhsOcopy :: Pattern
                     _patIcopy :: Pattern
@@ -383,11 +413,11 @@ sem_Pattern_Alias field_ attr_ (T_Pattern pat_) (T_Patterns parts_) =
                         (pat_ )
                     ( _partsIcopy,_partsIpp,_partsIppL) =
                         (parts_ )
-                in  ( _lhsOcopy,_lhsOpp)))
+                in  ( _lhsOcopy,_lhsOpp)) )
 sem_Pattern_Constr :: ConstructorIdent ->
-                      T_Patterns ->
-                      T_Pattern
-sem_Pattern_Constr name_ (T_Patterns pats_) =
+                      T_Patterns  ->
+                      T_Pattern 
+sem_Pattern_Constr name_ (T_Patterns pats_ )  =
     (T_Pattern (let _lhsOpp :: PP_Doc
                     _lhsOcopy :: Pattern
                     _patsIcopy :: Patterns
@@ -404,10 +434,10 @@ sem_Pattern_Constr name_ (T_Patterns pats_) =
                         _copy
                     ( _patsIcopy,_patsIpp,_patsIppL) =
                         (pats_ )
-                in  ( _lhsOcopy,_lhsOpp)))
-sem_Pattern_Irrefutable :: T_Pattern ->
-                           T_Pattern
-sem_Pattern_Irrefutable (T_Pattern pat_) =
+                in  ( _lhsOcopy,_lhsOpp)) )
+sem_Pattern_Irrefutable :: T_Pattern  ->
+                           T_Pattern 
+sem_Pattern_Irrefutable (T_Pattern pat_ )  =
     (T_Pattern (let _lhsOpp :: PP_Doc
                     _lhsOcopy :: Pattern
                     _patIcopy :: Pattern
@@ -423,11 +453,11 @@ sem_Pattern_Irrefutable (T_Pattern pat_) =
                         _copy
                     ( _patIcopy,_patIpp) =
                         (pat_ )
-                in  ( _lhsOcopy,_lhsOpp)))
+                in  ( _lhsOcopy,_lhsOpp)) )
 sem_Pattern_Product :: Pos ->
-                       T_Patterns ->
-                       T_Pattern
-sem_Pattern_Product pos_ (T_Patterns pats_) =
+                       T_Patterns  ->
+                       T_Pattern 
+sem_Pattern_Product pos_ (T_Patterns pats_ )  =
     (T_Pattern (let _lhsOpp :: PP_Doc
                     _lhsOcopy :: Pattern
                     _patsIcopy :: Patterns
@@ -444,10 +474,10 @@ sem_Pattern_Product pos_ (T_Patterns pats_) =
                         _copy
                     ( _patsIcopy,_patsIpp,_patsIppL) =
                         (pats_ )
-                in  ( _lhsOcopy,_lhsOpp)))
+                in  ( _lhsOcopy,_lhsOpp)) )
 sem_Pattern_Underscore :: Pos ->
-                          T_Pattern
-sem_Pattern_Underscore pos_ =
+                          T_Pattern 
+sem_Pattern_Underscore pos_  =
     (T_Pattern (let _lhsOpp :: PP_Doc
                     _lhsOcopy :: Pattern
                     -- "AbstractSyntaxDump.ag"(line 47, column 25)
@@ -459,18 +489,18 @@ sem_Pattern_Underscore pos_ =
                     -- self rule
                     _lhsOcopy =
                         _copy
-                in  ( _lhsOcopy,_lhsOpp)))
+                in  ( _lhsOcopy,_lhsOpp)) )
 -- Patterns ----------------------------------------------------
 {-
    visit 0:
       synthesized attributes:
-         copy                 : SELF
+         copy                 : SELF 
          pp                   : PP_Doc
          ppL                  : [PP_Doc]
    alternatives:
       alternative Cons:
-         child hd             : Pattern
-         child tl             : Patterns
+         child hd             : Pattern 
+         child tl             : Patterns 
          visit 0:
             local copy        : _
       alternative Nil:
@@ -478,22 +508,25 @@ sem_Pattern_Underscore pos_ =
             local copy        : _
 -}
 -- cata
-sem_Patterns :: Patterns ->
-                T_Patterns
-sem_Patterns list =
-    (Prelude.foldr sem_Patterns_Cons sem_Patterns_Nil (Prelude.map sem_Pattern list))
+sem_Patterns :: Patterns  ->
+                T_Patterns 
+sem_Patterns list  =
+    (Prelude.foldr sem_Patterns_Cons sem_Patterns_Nil (Prelude.map sem_Pattern list) )
 -- semantic domain
-newtype T_Patterns = T_Patterns (( Patterns,PP_Doc,([PP_Doc])))
-data Inh_Patterns = Inh_Patterns {}
-data Syn_Patterns = Syn_Patterns {copy_Syn_Patterns :: Patterns,pp_Syn_Patterns :: PP_Doc,ppL_Syn_Patterns :: [PP_Doc]}
-wrap_Patterns (T_Patterns sem) (Inh_Patterns ) =
+newtype T_Patterns  = T_Patterns (( Patterns,PP_Doc,([PP_Doc])))
+data Inh_Patterns  = Inh_Patterns {}
+data Syn_Patterns  = Syn_Patterns {copy_Syn_Patterns :: Patterns,pp_Syn_Patterns :: PP_Doc,ppL_Syn_Patterns :: [PP_Doc]}
+wrap_Patterns :: T_Patterns  ->
+                 Inh_Patterns  ->
+                 Syn_Patterns 
+wrap_Patterns (T_Patterns sem ) (Inh_Patterns )  =
     (let ( _lhsOcopy,_lhsOpp,_lhsOppL) =
              (sem )
-     in  (Syn_Patterns _lhsOcopy _lhsOpp _lhsOppL))
-sem_Patterns_Cons :: T_Pattern ->
-                     T_Patterns ->
-                     T_Patterns
-sem_Patterns_Cons (T_Pattern hd_) (T_Patterns tl_) =
+     in  (Syn_Patterns _lhsOcopy _lhsOpp _lhsOppL ))
+sem_Patterns_Cons :: T_Pattern  ->
+                     T_Patterns  ->
+                     T_Patterns 
+sem_Patterns_Cons (T_Pattern hd_ ) (T_Patterns tl_ )  =
     (T_Patterns (let _lhsOppL :: ([PP_Doc])
                      _lhsOpp :: PP_Doc
                      _lhsOcopy :: Patterns
@@ -518,8 +551,8 @@ sem_Patterns_Cons (T_Pattern hd_) (T_Patterns tl_) =
                          (hd_ )
                      ( _tlIcopy,_tlIpp,_tlIppL) =
                          (tl_ )
-                 in  ( _lhsOcopy,_lhsOpp,_lhsOppL)))
-sem_Patterns_Nil :: T_Patterns
+                 in  ( _lhsOcopy,_lhsOpp,_lhsOppL)) )
+sem_Patterns_Nil :: T_Patterns 
 sem_Patterns_Nil  =
     (T_Patterns (let _lhsOppL :: ([PP_Doc])
                      _lhsOpp :: PP_Doc
@@ -536,7 +569,7 @@ sem_Patterns_Nil  =
                      -- self rule
                      _lhsOcopy =
                          _copy
-                 in  ( _lhsOcopy,_lhsOpp,_lhsOppL)))
+                 in  ( _lhsOcopy,_lhsOpp,_lhsOppL)) )
 -- Production --------------------------------------------------
 {-
    visit 0:
@@ -545,29 +578,32 @@ sem_Patterns_Nil  =
    alternatives:
       alternative Production:
          child con            : {ConstructorIdent}
-         child children       : Children
-         child rules          : Rules
-         child typeSigs       : TypeSigs
+         child children       : Children 
+         child rules          : Rules 
+         child typeSigs       : TypeSigs 
 -}
 -- cata
-sem_Production :: Production ->
-                  T_Production
-sem_Production (Production _con _children _rules _typeSigs) =
-    (sem_Production_Production _con (sem_Children _children) (sem_Rules _rules) (sem_TypeSigs _typeSigs))
+sem_Production :: Production  ->
+                  T_Production 
+sem_Production (Production _con _children _rules _typeSigs )  =
+    (sem_Production_Production _con (sem_Children _children ) (sem_Rules _rules ) (sem_TypeSigs _typeSigs ) )
 -- semantic domain
-newtype T_Production = T_Production (( PP_Doc))
-data Inh_Production = Inh_Production {}
-data Syn_Production = Syn_Production {pp_Syn_Production :: PP_Doc}
-wrap_Production (T_Production sem) (Inh_Production ) =
+newtype T_Production  = T_Production (( PP_Doc))
+data Inh_Production  = Inh_Production {}
+data Syn_Production  = Syn_Production {pp_Syn_Production :: PP_Doc}
+wrap_Production :: T_Production  ->
+                   Inh_Production  ->
+                   Syn_Production 
+wrap_Production (T_Production sem ) (Inh_Production )  =
     (let ( _lhsOpp) =
              (sem )
-     in  (Syn_Production _lhsOpp))
+     in  (Syn_Production _lhsOpp ))
 sem_Production_Production :: ConstructorIdent ->
-                             T_Children ->
-                             T_Rules ->
-                             T_TypeSigs ->
-                             T_Production
-sem_Production_Production con_ (T_Children children_) (T_Rules rules_) (T_TypeSigs typeSigs_) =
+                             T_Children  ->
+                             T_Rules  ->
+                             T_TypeSigs  ->
+                             T_Production 
+sem_Production_Production con_ (T_Children children_ ) (T_Rules rules_ ) (T_TypeSigs typeSigs_ )  =
     (T_Production (let _lhsOpp :: PP_Doc
                        _childrenIpp :: PP_Doc
                        _childrenIppL :: ([PP_Doc])
@@ -584,7 +620,7 @@ sem_Production_Production con_ (T_Children children_) (T_Rules rules_) (T_TypeSi
                            (rules_ )
                        ( _typeSigsIpp,_typeSigsIppL) =
                            (typeSigs_ )
-                   in  ( _lhsOpp)))
+                   in  ( _lhsOpp)) )
 -- Productions -------------------------------------------------
 {-
    visit 0:
@@ -593,27 +629,30 @@ sem_Production_Production con_ (T_Children children_) (T_Rules rules_) (T_TypeSi
          ppL                  : [PP_Doc]
    alternatives:
       alternative Cons:
-         child hd             : Production
-         child tl             : Productions
+         child hd             : Production 
+         child tl             : Productions 
       alternative Nil:
 -}
 -- cata
-sem_Productions :: Productions ->
-                   T_Productions
-sem_Productions list =
-    (Prelude.foldr sem_Productions_Cons sem_Productions_Nil (Prelude.map sem_Production list))
+sem_Productions :: Productions  ->
+                   T_Productions 
+sem_Productions list  =
+    (Prelude.foldr sem_Productions_Cons sem_Productions_Nil (Prelude.map sem_Production list) )
 -- semantic domain
-newtype T_Productions = T_Productions (( PP_Doc,([PP_Doc])))
-data Inh_Productions = Inh_Productions {}
-data Syn_Productions = Syn_Productions {pp_Syn_Productions :: PP_Doc,ppL_Syn_Productions :: [PP_Doc]}
-wrap_Productions (T_Productions sem) (Inh_Productions ) =
+newtype T_Productions  = T_Productions (( PP_Doc,([PP_Doc])))
+data Inh_Productions  = Inh_Productions {}
+data Syn_Productions  = Syn_Productions {pp_Syn_Productions :: PP_Doc,ppL_Syn_Productions :: [PP_Doc]}
+wrap_Productions :: T_Productions  ->
+                    Inh_Productions  ->
+                    Syn_Productions 
+wrap_Productions (T_Productions sem ) (Inh_Productions )  =
     (let ( _lhsOpp,_lhsOppL) =
              (sem )
-     in  (Syn_Productions _lhsOpp _lhsOppL))
-sem_Productions_Cons :: T_Production ->
-                        T_Productions ->
-                        T_Productions
-sem_Productions_Cons (T_Production hd_) (T_Productions tl_) =
+     in  (Syn_Productions _lhsOpp _lhsOppL ))
+sem_Productions_Cons :: T_Production  ->
+                        T_Productions  ->
+                        T_Productions 
+sem_Productions_Cons (T_Production hd_ ) (T_Productions tl_ )  =
     (T_Productions (let _lhsOppL :: ([PP_Doc])
                         _lhsOpp :: PP_Doc
                         _hdIpp :: PP_Doc
@@ -629,8 +668,8 @@ sem_Productions_Cons (T_Production hd_) (T_Productions tl_) =
                             (hd_ )
                         ( _tlIpp,_tlIppL) =
                             (tl_ )
-                    in  ( _lhsOpp,_lhsOppL)))
-sem_Productions_Nil :: T_Productions
+                    in  ( _lhsOpp,_lhsOppL)) )
+sem_Productions_Nil :: T_Productions 
 sem_Productions_Nil  =
     (T_Productions (let _lhsOppL :: ([PP_Doc])
                         _lhsOpp :: PP_Doc
@@ -640,7 +679,7 @@ sem_Productions_Nil  =
                         -- use rule "AbstractSyntaxDump.ag"(line 17, column 58)
                         _lhsOpp =
                             empty
-                    in  ( _lhsOpp,_lhsOppL)))
+                    in  ( _lhsOpp,_lhsOppL)) )
 -- Rule --------------------------------------------------------
 {-
    visit 0:
@@ -648,30 +687,33 @@ sem_Productions_Nil  =
          pp                   : PP_Doc
    alternatives:
       alternative Rule:
-         child pattern        : Pattern
-         child rhs            : Expression
+         child pattern        : Pattern 
+         child rhs            : Expression 
          child owrt           : {Bool}
          child origin         : {String}
 -}
 -- cata
-sem_Rule :: Rule ->
-            T_Rule
-sem_Rule (Rule _pattern _rhs _owrt _origin) =
-    (sem_Rule_Rule (sem_Pattern _pattern) (sem_Expression _rhs) _owrt _origin)
+sem_Rule :: Rule  ->
+            T_Rule 
+sem_Rule (Rule _pattern _rhs _owrt _origin )  =
+    (sem_Rule_Rule (sem_Pattern _pattern ) (sem_Expression _rhs ) _owrt _origin )
 -- semantic domain
-newtype T_Rule = T_Rule (( PP_Doc))
-data Inh_Rule = Inh_Rule {}
-data Syn_Rule = Syn_Rule {pp_Syn_Rule :: PP_Doc}
-wrap_Rule (T_Rule sem) (Inh_Rule ) =
+newtype T_Rule  = T_Rule (( PP_Doc))
+data Inh_Rule  = Inh_Rule {}
+data Syn_Rule  = Syn_Rule {pp_Syn_Rule :: PP_Doc}
+wrap_Rule :: T_Rule  ->
+             Inh_Rule  ->
+             Syn_Rule 
+wrap_Rule (T_Rule sem ) (Inh_Rule )  =
     (let ( _lhsOpp) =
              (sem )
-     in  (Syn_Rule _lhsOpp))
-sem_Rule_Rule :: T_Pattern ->
-                 T_Expression ->
+     in  (Syn_Rule _lhsOpp ))
+sem_Rule_Rule :: T_Pattern  ->
+                 T_Expression  ->
                  Bool ->
                  String ->
-                 T_Rule
-sem_Rule_Rule (T_Pattern pattern_) (T_Expression rhs_) owrt_ origin_ =
+                 T_Rule 
+sem_Rule_Rule (T_Pattern pattern_ ) (T_Expression rhs_ ) owrt_ origin_  =
     (T_Rule (let _lhsOpp :: PP_Doc
                  _patternIcopy :: Pattern
                  _patternIpp :: PP_Doc
@@ -683,7 +725,7 @@ sem_Rule_Rule (T_Pattern pattern_) (T_Expression rhs_) owrt_ origin_ =
                      (pattern_ )
                  ( _rhsIpp) =
                      (rhs_ )
-             in  ( _lhsOpp)))
+             in  ( _lhsOpp)) )
 -- Rules -------------------------------------------------------
 {-
    visit 0:
@@ -692,27 +734,30 @@ sem_Rule_Rule (T_Pattern pattern_) (T_Expression rhs_) owrt_ origin_ =
          ppL                  : [PP_Doc]
    alternatives:
       alternative Cons:
-         child hd             : Rule
-         child tl             : Rules
+         child hd             : Rule 
+         child tl             : Rules 
       alternative Nil:
 -}
 -- cata
-sem_Rules :: Rules ->
-             T_Rules
-sem_Rules list =
-    (Prelude.foldr sem_Rules_Cons sem_Rules_Nil (Prelude.map sem_Rule list))
+sem_Rules :: Rules  ->
+             T_Rules 
+sem_Rules list  =
+    (Prelude.foldr sem_Rules_Cons sem_Rules_Nil (Prelude.map sem_Rule list) )
 -- semantic domain
-newtype T_Rules = T_Rules (( PP_Doc,([PP_Doc])))
-data Inh_Rules = Inh_Rules {}
-data Syn_Rules = Syn_Rules {pp_Syn_Rules :: PP_Doc,ppL_Syn_Rules :: [PP_Doc]}
-wrap_Rules (T_Rules sem) (Inh_Rules ) =
+newtype T_Rules  = T_Rules (( PP_Doc,([PP_Doc])))
+data Inh_Rules  = Inh_Rules {}
+data Syn_Rules  = Syn_Rules {pp_Syn_Rules :: PP_Doc,ppL_Syn_Rules :: [PP_Doc]}
+wrap_Rules :: T_Rules  ->
+              Inh_Rules  ->
+              Syn_Rules 
+wrap_Rules (T_Rules sem ) (Inh_Rules )  =
     (let ( _lhsOpp,_lhsOppL) =
              (sem )
-     in  (Syn_Rules _lhsOpp _lhsOppL))
-sem_Rules_Cons :: T_Rule ->
-                  T_Rules ->
-                  T_Rules
-sem_Rules_Cons (T_Rule hd_) (T_Rules tl_) =
+     in  (Syn_Rules _lhsOpp _lhsOppL ))
+sem_Rules_Cons :: T_Rule  ->
+                  T_Rules  ->
+                  T_Rules 
+sem_Rules_Cons (T_Rule hd_ ) (T_Rules tl_ )  =
     (T_Rules (let _lhsOppL :: ([PP_Doc])
                   _lhsOpp :: PP_Doc
                   _hdIpp :: PP_Doc
@@ -728,8 +773,8 @@ sem_Rules_Cons (T_Rule hd_) (T_Rules tl_) =
                       (hd_ )
                   ( _tlIpp,_tlIppL) =
                       (tl_ )
-              in  ( _lhsOpp,_lhsOppL)))
-sem_Rules_Nil :: T_Rules
+              in  ( _lhsOpp,_lhsOppL)) )
+sem_Rules_Nil :: T_Rules 
 sem_Rules_Nil  =
     (T_Rules (let _lhsOppL :: ([PP_Doc])
                   _lhsOpp :: PP_Doc
@@ -739,7 +784,7 @@ sem_Rules_Nil  =
                   -- use rule "AbstractSyntaxDump.ag"(line 17, column 58)
                   _lhsOpp =
                       empty
-              in  ( _lhsOpp,_lhsOppL)))
+              in  ( _lhsOpp,_lhsOppL)) )
 -- TypeSig -----------------------------------------------------
 {-
    visit 0:
@@ -751,27 +796,30 @@ sem_Rules_Nil  =
          child tp             : {Type}
 -}
 -- cata
-sem_TypeSig :: TypeSig ->
-               T_TypeSig
-sem_TypeSig (TypeSig _name _tp) =
-    (sem_TypeSig_TypeSig _name _tp)
+sem_TypeSig :: TypeSig  ->
+               T_TypeSig 
+sem_TypeSig (TypeSig _name _tp )  =
+    (sem_TypeSig_TypeSig _name _tp )
 -- semantic domain
-newtype T_TypeSig = T_TypeSig (( PP_Doc))
-data Inh_TypeSig = Inh_TypeSig {}
-data Syn_TypeSig = Syn_TypeSig {pp_Syn_TypeSig :: PP_Doc}
-wrap_TypeSig (T_TypeSig sem) (Inh_TypeSig ) =
+newtype T_TypeSig  = T_TypeSig (( PP_Doc))
+data Inh_TypeSig  = Inh_TypeSig {}
+data Syn_TypeSig  = Syn_TypeSig {pp_Syn_TypeSig :: PP_Doc}
+wrap_TypeSig :: T_TypeSig  ->
+                Inh_TypeSig  ->
+                Syn_TypeSig 
+wrap_TypeSig (T_TypeSig sem ) (Inh_TypeSig )  =
     (let ( _lhsOpp) =
              (sem )
-     in  (Syn_TypeSig _lhsOpp))
+     in  (Syn_TypeSig _lhsOpp ))
 sem_TypeSig_TypeSig :: Identifier ->
                        Type ->
-                       T_TypeSig
-sem_TypeSig_TypeSig name_ tp_ =
+                       T_TypeSig 
+sem_TypeSig_TypeSig name_ tp_  =
     (T_TypeSig (let _lhsOpp :: PP_Doc
                     -- "AbstractSyntaxDump.ag"(line 41, column 33)
                     _lhsOpp =
                         ppNestInfo ["TypeSig","TypeSig"] [pp name_, ppShow tp_] [] []
-                in  ( _lhsOpp)))
+                in  ( _lhsOpp)) )
 -- TypeSigs ----------------------------------------------------
 {-
    visit 0:
@@ -780,27 +828,30 @@ sem_TypeSig_TypeSig name_ tp_ =
          ppL                  : [PP_Doc]
    alternatives:
       alternative Cons:
-         child hd             : TypeSig
-         child tl             : TypeSigs
+         child hd             : TypeSig 
+         child tl             : TypeSigs 
       alternative Nil:
 -}
 -- cata
-sem_TypeSigs :: TypeSigs ->
-                T_TypeSigs
-sem_TypeSigs list =
-    (Prelude.foldr sem_TypeSigs_Cons sem_TypeSigs_Nil (Prelude.map sem_TypeSig list))
+sem_TypeSigs :: TypeSigs  ->
+                T_TypeSigs 
+sem_TypeSigs list  =
+    (Prelude.foldr sem_TypeSigs_Cons sem_TypeSigs_Nil (Prelude.map sem_TypeSig list) )
 -- semantic domain
-newtype T_TypeSigs = T_TypeSigs (( PP_Doc,([PP_Doc])))
-data Inh_TypeSigs = Inh_TypeSigs {}
-data Syn_TypeSigs = Syn_TypeSigs {pp_Syn_TypeSigs :: PP_Doc,ppL_Syn_TypeSigs :: [PP_Doc]}
-wrap_TypeSigs (T_TypeSigs sem) (Inh_TypeSigs ) =
+newtype T_TypeSigs  = T_TypeSigs (( PP_Doc,([PP_Doc])))
+data Inh_TypeSigs  = Inh_TypeSigs {}
+data Syn_TypeSigs  = Syn_TypeSigs {pp_Syn_TypeSigs :: PP_Doc,ppL_Syn_TypeSigs :: [PP_Doc]}
+wrap_TypeSigs :: T_TypeSigs  ->
+                 Inh_TypeSigs  ->
+                 Syn_TypeSigs 
+wrap_TypeSigs (T_TypeSigs sem ) (Inh_TypeSigs )  =
     (let ( _lhsOpp,_lhsOppL) =
              (sem )
-     in  (Syn_TypeSigs _lhsOpp _lhsOppL))
-sem_TypeSigs_Cons :: T_TypeSig ->
-                     T_TypeSigs ->
-                     T_TypeSigs
-sem_TypeSigs_Cons (T_TypeSig hd_) (T_TypeSigs tl_) =
+     in  (Syn_TypeSigs _lhsOpp _lhsOppL ))
+sem_TypeSigs_Cons :: T_TypeSig  ->
+                     T_TypeSigs  ->
+                     T_TypeSigs 
+sem_TypeSigs_Cons (T_TypeSig hd_ ) (T_TypeSigs tl_ )  =
     (T_TypeSigs (let _lhsOppL :: ([PP_Doc])
                      _lhsOpp :: PP_Doc
                      _hdIpp :: PP_Doc
@@ -816,8 +867,8 @@ sem_TypeSigs_Cons (T_TypeSig hd_) (T_TypeSigs tl_) =
                          (hd_ )
                      ( _tlIpp,_tlIppL) =
                          (tl_ )
-                 in  ( _lhsOpp,_lhsOppL)))
-sem_TypeSigs_Nil :: T_TypeSigs
+                 in  ( _lhsOpp,_lhsOppL)) )
+sem_TypeSigs_Nil :: T_TypeSigs 
 sem_TypeSigs_Nil  =
     (T_TypeSigs (let _lhsOppL :: ([PP_Doc])
                      _lhsOpp :: PP_Doc
@@ -827,4 +878,4 @@ sem_TypeSigs_Nil  =
                      -- use rule "AbstractSyntaxDump.ag"(line 17, column 58)
                      _lhsOpp =
                          empty
-                 in  ( _lhsOpp,_lhsOppL)))
+                 in  ( _lhsOpp,_lhsOppL)) )
\ No newline at end of file
