@@ -1,11 +1,13 @@
--- UUAGC 0.9.5 (Code.ag)
+
+
+-- UUAGC 0.9.14 (Code.ag)
 module Code where
 
 import Pretty
 import Patterns
 import Data.List(partition)
 import Data.Set(Set)
-import qualified UU.DData.Set as Set
+import qualified Data.Set as Set
 import Data.Map(Map)
 import qualified Data.Map as Map
 
@@ -28,43 +30,43 @@ mkTupleLhs  unbox noInh comps | not unbox || noInh || length comps == 1 = TupleL
 {-
    alternatives:
       alternative CaseAlt:
-         child left           : Lhs
-         child expr           : Expr
+         child left           : Lhs 
+         child expr           : Expr 
 -}
-data CaseAlt = CaseAlt (Lhs) (Expr)
+data CaseAlt  = CaseAlt (Lhs) (Expr) 
 -- CaseAlts ----------------------------------------------------
 {-
    alternatives:
       alternative Cons:
-         child hd             : CaseAlt
-         child tl             : CaseAlts
+         child hd             : CaseAlt 
+         child tl             : CaseAlts 
       alternative Nil:
 -}
-type CaseAlts = [CaseAlt]
+type CaseAlts  = [(CaseAlt)]
 -- Chunk -------------------------------------------------------
 {-
    alternatives:
       alternative Chunk:
          child name           : {String}
-         child comment        : Decl
-         child info           : Decls
-         child dataDef        : Decls
-         child cataFun        : Decls
-         child semDom         : Decls
-         child semWrapper     : Decls
-         child semFunctions   : Decls
+         child comment        : Decl 
+         child info           : Decls 
+         child dataDef        : Decls 
+         child cataFun        : Decls 
+         child semDom         : Decls 
+         child semWrapper     : Decls 
+         child semFunctions   : Decls 
          child semNames       : {[String]}
 -}
-data Chunk = Chunk (String) (Decl) (Decls) (Decls) (Decls) (Decls) (Decls) (Decls) ([String])
+data Chunk  = Chunk (String) (Decl) (Decls) (Decls) (Decls) (Decls) (Decls) (Decls) ([String]) 
 -- Chunks ------------------------------------------------------
 {-
    alternatives:
       alternative Cons:
-         child hd             : Chunk
-         child tl             : Chunks
+         child hd             : Chunk 
+         child tl             : Chunks 
       alternative Nil:
 -}
-type Chunks = [Chunk]
+type Chunks  = [(Chunk)]
 -- DataAlt -----------------------------------------------------
 {-
    alternatives:
@@ -75,17 +77,17 @@ type Chunks = [Chunk]
          child name           : {String}
          child args           : {[(String,String)]}
 -}
-data DataAlt = DataAlt (String) ([String])
-             | Record (String) ([(String,String)])
+data DataAlt  = DataAlt (String) ([String]) 
+              | Record (String) ([(String,String)]) 
 -- DataAlts ----------------------------------------------------
 {-
    alternatives:
       alternative Cons:
-         child hd             : DataAlt
-         child tl             : DataAlts
+         child hd             : DataAlt 
+         child tl             : DataAlts 
       alternative Nil:
 -}
-type DataAlts = [DataAlt]
+type DataAlts  = [(DataAlt)]
 -- Decl --------------------------------------------------------
 {-
    alternatives:
@@ -94,109 +96,109 @@ type DataAlts = [DataAlt]
       alternative Data:
          child name           : {String}
          child params         : {[String]}
-         child alts           : DataAlts
+         child alts           : DataAlts 
          child strict         : {Bool}
          child derivings      : {[String]}
       alternative Decl:
-         child left           : Lhs
-         child rhs            : Expr
+         child left           : Lhs 
+         child rhs            : Expr 
          child binds          : {Set String}
          child uses           : {Set String}
       alternative NewType:
          child name           : {String}
          child params         : {[String]}
          child con            : {String}
-         child tp             : Type
+         child tp             : Type 
       alternative PragmaDecl:
          child txt            : {String}
       alternative TSig:
          child name           : {String}
-         child tp             : Type
+         child tp             : Type 
       alternative Type:
          child name           : {String}
          child params         : {[String]}
-         child tp             : Type
+         child tp             : Type 
 -}
-data Decl = Comment (String)
-          | Data (String) ([String]) (DataAlts) (Bool) ([String])
-          | Decl (Lhs) (Expr) (Set String) (Set String)
-          | NewType (String) ([String]) (String) (Type)
-          | PragmaDecl (String)
-          | TSig (String) (Type)
-          | Type (String) ([String]) (Type)
+data Decl  = Comment (String) 
+           | Data (String) ([String]) (DataAlts) (Bool) ([String]) 
+           | Decl (Lhs) (Expr) (Set String) (Set String) 
+           | NewType (String) ([String]) (String) (Type) 
+           | PragmaDecl (String) 
+           | TSig (String) (Type) 
+           | Type (String) ([String]) (Type) 
 -- Decls -------------------------------------------------------
 {-
    alternatives:
       alternative Cons:
-         child hd             : Decl
-         child tl             : Decls
+         child hd             : Decl 
+         child tl             : Decls 
       alternative Nil:
 -}
-type Decls = [Decl]
+type Decls  = [(Decl)]
 -- Expr --------------------------------------------------------
 {-
    alternatives:
       alternative App:
          child name           : {String}
-         child args           : Exprs
+         child args           : Exprs 
       alternative Case:
-         child expr           : Expr
-         child alts           : CaseAlts
+         child expr           : Expr 
+         child alts           : CaseAlts 
       alternative Lambda:
-         child args           : Exprs
-         child body           : Expr
+         child args           : Exprs 
+         child body           : Expr 
       alternative Let:
-         child decls          : Decls
-         child body           : Expr
+         child decls          : Decls 
+         child body           : Expr 
       alternative LineExpr:
-         child expr           : Expr
+         child expr           : Expr 
       alternative PragmaExpr:
          child onLeftSide     : {Bool}
          child onNewLine      : {Bool}
          child txt            : {String}
-         child expr           : Expr
+         child expr           : Expr 
       alternative SimpleExpr:
          child txt            : {String}
       alternative TextExpr:
          child lns            : {[String]}
       alternative Trace:
          child txt            : {String}
-         child expr           : Expr
+         child expr           : Expr 
       alternative TupleExpr:
-         child exprs          : Exprs
+         child exprs          : Exprs 
       alternative TypedExpr:
-         child expr           : Expr
-         child tp             : Type
+         child expr           : Expr 
+         child tp             : Type 
       alternative UnboxedTupleExpr:
-         child exprs          : Exprs
+         child exprs          : Exprs 
 -}
-data Expr = App (String) (Exprs)
-          | Case (Expr) (CaseAlts)
-          | Lambda (Exprs) (Expr)
-          | Let (Decls) (Expr)
-          | LineExpr (Expr)
-          | PragmaExpr (Bool) (Bool) (String) (Expr)
-          | SimpleExpr (String)
-          | TextExpr ([String])
-          | Trace (String) (Expr)
-          | TupleExpr (Exprs)
-          | TypedExpr (Expr) (Type)
-          | UnboxedTupleExpr (Exprs)
+data Expr  = App (String) (Exprs) 
+           | Case (Expr) (CaseAlts) 
+           | Lambda (Exprs) (Expr) 
+           | Let (Decls) (Expr) 
+           | LineExpr (Expr) 
+           | PragmaExpr (Bool) (Bool) (String) (Expr) 
+           | SimpleExpr (String) 
+           | TextExpr ([String]) 
+           | Trace (String) (Expr) 
+           | TupleExpr (Exprs) 
+           | TypedExpr (Expr) (Type) 
+           | UnboxedTupleExpr (Exprs) 
 -- Exprs -------------------------------------------------------
 {-
    alternatives:
       alternative Cons:
-         child hd             : Expr
-         child tl             : Exprs
+         child hd             : Expr 
+         child tl             : Exprs 
       alternative Nil:
 -}
-type Exprs = [Expr]
+type Exprs  = [(Expr)]
 -- Lhs ---------------------------------------------------------
 {-
    alternatives:
       alternative Fun:
          child name           : {String}
-         child args           : Exprs
+         child args           : Exprs 
       alternative Pattern3:
          child pat3           : {Pattern}
       alternative Pattern3SM:
@@ -205,53 +207,58 @@ type Exprs = [Expr]
          child comps          : {[String]}
       alternative UnboxedTupleLhs:
          child comps          : {[String]}
+      alternative Unwrap:
+         child name           : {String}
+         child sub            : Lhs 
 -}
-data Lhs = Fun (String) (Exprs)
-         | Pattern3 (Pattern)
-         | Pattern3SM (Pattern)
-         | TupleLhs ([String])
-         | UnboxedTupleLhs ([String])
+data Lhs  = Fun (String) (Exprs) 
+          | Pattern3 (Pattern) 
+          | Pattern3SM (Pattern) 
+          | TupleLhs ([String]) 
+          | UnboxedTupleLhs ([String]) 
+          | Unwrap (String) (Lhs) 
 -- Program -----------------------------------------------------
 {-
    alternatives:
       alternative Program:
-         child chunks         : Chunks
+         child chunks         : Chunks 
 -}
-data Program = Program (Chunks)
+data Program  = Program (Chunks) 
 -- Type --------------------------------------------------------
 {-
    alternatives:
       alternative Arr:
-         child left           : Type
-         child right          : Type
+         child left           : Type 
+         child right          : Type 
       alternative CtxApp:
          child left           : {[(String, [String])]}
-         child right          : Type
+         child right          : Type 
       alternative List:
-         child tp             : Type
+         child tp             : Type 
       alternative SimpleType:
          child txt            : {String}
       alternative TupleType:
-         child tps            : Types
+         child tps            : Types 
       alternative TypeApp:
-         child func           : Type
-         child args           : Types
+         child func           : Type 
+         child args           : Types 
       alternative UnboxedTupleType:
-         child tps            : Types
+         child tps            : Types 
 -}
-data Type = Arr (Type) (Type)
-          | CtxApp ([(String, [String])]) (Type)
-          | List (Type)
-          | SimpleType (String)
-          | TupleType (Types)
-          | TypeApp (Type) (Types)
-          | UnboxedTupleType (Types)
+data Type  = Arr (Type) (Type) 
+           | CtxApp ([(String, [String])]) (Type) 
+           | List (Type) 
+           | SimpleType (String) 
+           | TupleType (Types) 
+           | TypeApp (Type) (Types) 
+           | UnboxedTupleType (Types) 
+           deriving ( Show)
 -- Types -------------------------------------------------------
 {-
    alternatives:
       alternative Cons:
-         child hd             : Type
-         child tl             : Types
+         child hd             : Type 
+         child tl             : Types 
       alternative Nil:
 -}
-type Types = [Type]
+type Types  = [(Type)]
\ No newline at end of file
