@@ -1,4 +1,6 @@
--- UUAGC 0.9.5 (CodeSyntax.ag)
+
+
+-- UUAGC 0.9.14 (CodeSyntax.ag)
 module CodeSyntax where
 
 import Patterns
@@ -12,19 +14,19 @@ import Data.Set(Set)
          child typeSyns       : {TypeSyns}
          child derivings      : {Derivings}
          child wrappers       : {Set NontermIdent}
-         child nonts          : CNonterminals
+         child nonts          : CNonterminals 
          child pragmas        : {PragmaMap}
          child paramMap       : {ParamMap}
          child contextMap     : {ContextMap}
 -}
-data CGrammar = CGrammar (TypeSyns) (Derivings) (Set NontermIdent) (CNonterminals) (PragmaMap) (ParamMap) (ContextMap)
+data CGrammar  = CGrammar (TypeSyns) (Derivings) (Set NontermIdent) (CNonterminals) (PragmaMap) (ParamMap) (ContextMap) 
 -- CInterface --------------------------------------------------
 {-
    alternatives:
       alternative CInterface:
-         child seg            : CSegments
+         child seg            : CSegments 
 -}
-data CInterface = CInterface (CSegments)
+data CInterface  = CInterface (CSegments) 
 -- CNonterminal ------------------------------------------------
 {-
    alternatives:
@@ -33,38 +35,38 @@ data CInterface = CInterface (CSegments)
          child params         : {[Identifier]}
          child inh            : {Attributes}
          child syn            : {Attributes}
-         child prods          : CProductions
-         child inter          : CInterface
+         child prods          : CProductions 
+         child inter          : CInterface 
 -}
-data CNonterminal = CNonterminal (NontermIdent) ([Identifier]) (Attributes) (Attributes) (CProductions) (CInterface)
+data CNonterminal  = CNonterminal (NontermIdent) ([Identifier]) (Attributes) (Attributes) (CProductions) (CInterface) 
 -- CNonterminals -----------------------------------------------
 {-
    alternatives:
       alternative Cons:
-         child hd             : CNonterminal
-         child tl             : CNonterminals
+         child hd             : CNonterminal 
+         child tl             : CNonterminals 
       alternative Nil:
 -}
-type CNonterminals = [CNonterminal]
+type CNonterminals  = [(CNonterminal)]
 -- CProduction -------------------------------------------------
 {-
    alternatives:
       alternative CProduction:
          child con            : {ConstructorIdent}
-         child visits         : CVisits
+         child visits         : CVisits 
          child children       : {[(Identifier,Type,Bool)]}
          child terminals      : {[Identifier]}
 -}
-data CProduction = CProduction (ConstructorIdent) (CVisits) ([(Identifier,Type,Bool)]) ([Identifier])
+data CProduction  = CProduction (ConstructorIdent) (CVisits) ([(Identifier,Type,Bool)]) ([Identifier]) 
 -- CProductions ------------------------------------------------
 {-
    alternatives:
       alternative Cons:
-         child hd             : CProduction
-         child tl             : CProductions
+         child hd             : CProduction 
+         child tl             : CProductions 
       alternative Nil:
 -}
-type CProductions = [CProduction]
+type CProductions  = [(CProduction)]
 -- CRule -------------------------------------------------------
 {-
    alternatives:
@@ -91,8 +93,8 @@ type CProductions = [CProduction]
          child origin         : {String}
          child uses           : {Set (Identifier, Identifier)}
 -}
-data CRule = CChildVisit (Identifier) (NontermIdent) (Int) (Attributes) (Attributes) (Bool)
-           | CRule (Identifier) (Bool) (Bool) (NontermIdent) (ConstructorIdent) (Identifier) (Maybe NontermIdent) (Maybe Type) (Pattern) ([String]) (Map Int (Identifier,Identifier,Maybe Type)) (Bool) (String) (Set (Identifier, Identifier))
+data CRule  = CChildVisit (Identifier) (NontermIdent) (Int) (Attributes) (Attributes) (Bool) 
+            | CRule (Identifier) (Bool) (Bool) (NontermIdent) (ConstructorIdent) (Identifier) (Maybe NontermIdent) (Maybe Type) (Pattern) ([String]) (Map Int (Identifier,Identifier,Maybe Type)) (Bool) (String) (Set (Identifier, Identifier)) 
 -- CSegment ----------------------------------------------------
 {-
    alternatives:
@@ -100,42 +102,42 @@ data CRule = CChildVisit (Identifier) (NontermIdent) (Int) (Attributes) (Attribu
          child inh            : {Attributes}
          child syn            : {Attributes}
 -}
-data CSegment = CSegment (Attributes) (Attributes)
+data CSegment  = CSegment (Attributes) (Attributes) 
 -- CSegments ---------------------------------------------------
 {-
    alternatives:
       alternative Cons:
-         child hd             : CSegment
-         child tl             : CSegments
+         child hd             : CSegment 
+         child tl             : CSegments 
       alternative Nil:
 -}
-type CSegments = [CSegment]
+type CSegments  = [(CSegment)]
 -- CVisit ------------------------------------------------------
 {-
    alternatives:
       alternative CVisit:
          child inh            : {Attributes}
          child syn            : {Attributes}
-         child vss            : Sequence
-         child intra          : Sequence
+         child vss            : Sequence 
+         child intra          : Sequence 
          child ordered        : {Bool}
 -}
-data CVisit = CVisit (Attributes) (Attributes) (Sequence) (Sequence) (Bool)
+data CVisit  = CVisit (Attributes) (Attributes) (Sequence) (Sequence) (Bool) 
 -- CVisits -----------------------------------------------------
 {-
    alternatives:
       alternative Cons:
-         child hd             : CVisit
-         child tl             : CVisits
+         child hd             : CVisit 
+         child tl             : CVisits 
       alternative Nil:
 -}
-type CVisits = [CVisit]
+type CVisits  = [(CVisit)]
 -- Sequence ----------------------------------------------------
 {-
    alternatives:
       alternative Cons:
-         child hd             : CRule
-         child tl             : Sequence
+         child hd             : CRule 
+         child tl             : Sequence 
       alternative Nil:
 -}
-type Sequence = [CRule]
+type Sequence  = [(CRule)]
\ No newline at end of file
