@@ -1,4 +1,6 @@
--- UUAGC 0.9.5 (ErrorMessages.ag)
+
+
+-- UUAGC 0.9.14 (ErrorMessages.ag)
 module ErrorMessages where
 
 import UU.Scanner.Position(Pos)
@@ -56,6 +58,10 @@ import CommonTypes
       alternative DupSynonym:
          child nt             : {NontermIdent}
          child occ1           : {NontermIdent}
+      alternative DupUnique:
+         child nt             : {NontermIdent}
+         child con            : {ConstructorIdent}
+         child attr           : {Identifier}
       alternative InducedCirc:
          child nt             : {NontermIdent}
          child cinter         : {CInterface}
@@ -81,10 +87,16 @@ import CommonTypes
          child con            : {ConstructorIdent}
          child field          : {Identifier}
          child attr           : {Identifier}
+      alternative MissingSyn:
+         child nt             : {NontermIdent}
+         child attr           : {Identifier}
       alternative MissingTypeSig:
          child nt             : {NontermIdent}
          child con            : {ConstructorIdent}
          child attr           : {Identifier}
+      alternative MissingUnique:
+         child nt             : {NontermIdent}
+         child attr           : {Identifier}
       alternative ParserError:
          child pos            : {Pos}
          child problem        : {String}
@@ -114,37 +126,40 @@ import CommonTypes
       alternative UndefNont:
          child nt             : {NontermIdent}
 -}
-data Error = ChildAsLocal (NontermIdent) (ConstructorIdent) (Identifier)
-           | CustomError (Bool) (Pos) (PP_Doc)
-           | CyclicSet (Identifier)
-           | DirectCirc (NontermIdent) (Bool) ([((Identifier,Identifier),[String],[String])])
-           | DupAlt (NontermIdent) (ConstructorIdent) (ConstructorIdent)
-           | DupChild (NontermIdent) (ConstructorIdent) (Identifier) (Identifier)
-           | DupInhAttr (NontermIdent) (Identifier) (Identifier)
-           | DupRule (NontermIdent) (ConstructorIdent) (Identifier) (Identifier) (Identifier)
-           | DupSet (NontermIdent) (NontermIdent)
-           | DupSig (NontermIdent) (ConstructorIdent) (Identifier)
-           | DupSynAttr (NontermIdent) (Identifier) (Identifier)
-           | DupSynonym (NontermIdent) (NontermIdent)
-           | InducedCirc (NontermIdent) (CInterface) ([((Identifier,Identifier),[String],[String])])
-           | InstCirc (NontermIdent) (ConstructorIdent) (Identifier) (Bool) ([String])
-           | LocalCirc (NontermIdent) (ConstructorIdent) (Identifier) (Bool) ([String])
-           | MissingInstSig (NontermIdent) (ConstructorIdent) (Identifier)
-           | MissingRule (NontermIdent) (ConstructorIdent) (Identifier) (Identifier)
-           | MissingTypeSig (NontermIdent) (ConstructorIdent) (Identifier)
-           | ParserError (Pos) (String) (String)
-           | SuperfluousRule (NontermIdent) (ConstructorIdent) (Identifier) (Identifier)
-           | UndefAlt (NontermIdent) (ConstructorIdent)
-           | UndefAttr (NontermIdent) (ConstructorIdent) (Identifier) (Identifier) (Bool)
-           | UndefChild (NontermIdent) (ConstructorIdent) (Identifier)
-           | UndefLocal (NontermIdent) (ConstructorIdent) (Identifier)
-           | UndefNont (NontermIdent)
+data Error  = ChildAsLocal (NontermIdent) (ConstructorIdent) (Identifier) 
+            | CustomError (Bool) (Pos) (PP_Doc) 
+            | CyclicSet (Identifier) 
+            | DirectCirc (NontermIdent) (Bool) ([((Identifier,Identifier),[String],[String])]) 
+            | DupAlt (NontermIdent) (ConstructorIdent) (ConstructorIdent) 
+            | DupChild (NontermIdent) (ConstructorIdent) (Identifier) (Identifier) 
+            | DupInhAttr (NontermIdent) (Identifier) (Identifier) 
+            | DupRule (NontermIdent) (ConstructorIdent) (Identifier) (Identifier) (Identifier) 
+            | DupSet (NontermIdent) (NontermIdent) 
+            | DupSig (NontermIdent) (ConstructorIdent) (Identifier) 
+            | DupSynAttr (NontermIdent) (Identifier) (Identifier) 
+            | DupSynonym (NontermIdent) (NontermIdent) 
+            | DupUnique (NontermIdent) (ConstructorIdent) (Identifier) 
+            | InducedCirc (NontermIdent) (CInterface) ([((Identifier,Identifier),[String],[String])]) 
+            | InstCirc (NontermIdent) (ConstructorIdent) (Identifier) (Bool) ([String]) 
+            | LocalCirc (NontermIdent) (ConstructorIdent) (Identifier) (Bool) ([String]) 
+            | MissingInstSig (NontermIdent) (ConstructorIdent) (Identifier) 
+            | MissingRule (NontermIdent) (ConstructorIdent) (Identifier) (Identifier) 
+            | MissingSyn (NontermIdent) (Identifier) 
+            | MissingTypeSig (NontermIdent) (ConstructorIdent) (Identifier) 
+            | MissingUnique (NontermIdent) (Identifier) 
+            | ParserError (Pos) (String) (String) 
+            | SuperfluousRule (NontermIdent) (ConstructorIdent) (Identifier) (Identifier) 
+            | UndefAlt (NontermIdent) (ConstructorIdent) 
+            | UndefAttr (NontermIdent) (ConstructorIdent) (Identifier) (Identifier) (Bool) 
+            | UndefChild (NontermIdent) (ConstructorIdent) (Identifier) 
+            | UndefLocal (NontermIdent) (ConstructorIdent) (Identifier) 
+            | UndefNont (NontermIdent) 
 -- Errors ------------------------------------------------------
 {-
    alternatives:
       alternative Cons:
-         child hd             : Error
-         child tl             : Errors
+         child hd             : Error 
+         child tl             : Errors 
       alternative Nil:
 -}
-type Errors = [Error]
+type Errors  = [(Error)]
\ No newline at end of file
