@@ -1,4 +1,6 @@
--- UUAGC 0.9.5 (HsToken.ag)
+
+
+-- UUAGC 0.9.14 (HsToken.ag)
 module HsToken where
 
 import CommonTypes
@@ -28,25 +30,25 @@ import UU.Scanner.Position(Pos)
          child value          : {String}
          child pos            : {Pos}
 -}
-data HsToken = AGField (Identifier) (Identifier) (Pos) (Maybe String)
-             | AGLocal (Identifier) (Pos) (Maybe String)
-             | CharToken (String) (Pos)
-             | Err (String) (Pos)
-             | HsToken (String) (Pos)
-             | StrToken (String) (Pos)
+data HsToken  = AGField (Identifier) (Identifier) (Pos) (Maybe String) 
+              | AGLocal (Identifier) (Pos) (Maybe String) 
+              | CharToken (String) (Pos) 
+              | Err (String) (Pos) 
+              | HsToken (String) (Pos) 
+              | StrToken (String) (Pos) 
 -- HsTokens ----------------------------------------------------
 {-
    alternatives:
       alternative Cons:
-         child hd             : HsToken
-         child tl             : HsTokens
+         child hd             : HsToken 
+         child tl             : HsTokens 
       alternative Nil:
 -}
-type HsTokens = [HsToken]
+type HsTokens  = [(HsToken)]
 -- HsTokensRoot ------------------------------------------------
 {-
    alternatives:
       alternative HsTokensRoot:
-         child tokens         : HsTokens
+         child tokens         : HsTokens 
 -}
-data HsTokensRoot = HsTokensRoot (HsTokens)
+data HsTokensRoot  = HsTokensRoot (HsTokens) 
\ No newline at end of file
