@@ -1,5 +1,6 @@
 
--- UUAGC 0.9.5 (Interfaces.ag)
+
+-- UUAGC 0.9.14 (Interfaces.ag)
 module Interfaces where
 
 import CommonTypes
@@ -10,7 +11,7 @@ import SequentialTypes
       alternative IRoot:
          child inters         : Interfaces 
 -}
-data IRoot = IRoot (Interfaces) 
+data IRoot  = IRoot (Interfaces) 
 -- Interface ---------------------------------------------------
 {-
    alternatives:
@@ -19,7 +20,7 @@ data IRoot = IRoot (Interfaces)
          child cons           : {[ConstructorIdent]}
          child seg            : Segments 
 -}
-data Interface = Interface (NontermIdent) ([ConstructorIdent]) (Segments) 
+data Interface  = Interface (NontermIdent) ([ConstructorIdent]) (Segments) 
 -- Interfaces --------------------------------------------------
 {-
    alternatives:
@@ -28,7 +29,7 @@ data Interface = Interface (NontermIdent) ([ConstructorIdent]) (Segments)
          child tl             : Interfaces 
       alternative Nil:
 -}
-type Interfaces = [Interface]
+type Interfaces  = [(Interface)]
 -- Segment -----------------------------------------------------
 {-
    alternatives:
@@ -36,7 +37,7 @@ type Interfaces = [Interface]
          child inh            : {[Vertex]}
          child syn            : {[Vertex]}
 -}
-data Segment = Segment ([Vertex]) ([Vertex]) 
+data Segment  = Segment ([Vertex]) ([Vertex]) 
 -- Segments ----------------------------------------------------
 {-
    alternatives:
@@ -45,4 +46,4 @@ data Segment = Segment ([Vertex]) ([Vertex])
          child tl             : Segments 
       alternative Nil:
 -}
-type Segments = [Segment]
\ No newline at end of file
+type Segments  = [(Segment)]
\ No newline at end of file
