@@ -1,4 +1,6 @@
--- UUAGC 0.9.5 (Patterns.ag)
+
+
+-- UUAGC 0.9.14 (Patterns.ag)
 module Patterns where
 
 -- Patterns.ag imports
@@ -8,27 +10,27 @@ import CommonTypes (ConstructorIdent,Identifier)
 {-
    visit 0:
       synthesized attribute:
-         copy                 : SELF
+         copy                 : SELF 
    alternatives:
       alternative Alias:
          child field          : {Identifier}
          child attr           : {Identifier}
-         child pat            : Pattern
-         child parts          : Patterns
+         child pat            : Pattern 
+         child parts          : Patterns 
          visit 0:
             local copy        : _
       alternative Constr:
          child name           : {ConstructorIdent}
-         child pats           : Patterns
+         child pats           : Patterns 
          visit 0:
             local copy        : _
       alternative Irrefutable:
-         child pat            : Pattern
+         child pat            : Pattern 
          visit 0:
             local copy        : _
       alternative Product:
          child pos            : {Pos}
-         child pats           : Patterns
+         child pats           : Patterns 
          visit 0:
             local copy        : _
       alternative Underscore:
@@ -36,25 +38,25 @@ import CommonTypes (ConstructorIdent,Identifier)
          visit 0:
             local copy        : _
 -}
-data Pattern = Alias (Identifier) (Identifier) (Pattern) (Patterns)
-             | Constr (ConstructorIdent) (Patterns)
-             | Irrefutable (Pattern)
-             | Product (Pos) (Patterns)
-             | Underscore (Pos)
-             deriving ( Show)
+data Pattern  = Alias (Identifier) (Identifier) (Pattern) (Patterns) 
+              | Constr (ConstructorIdent) (Patterns) 
+              | Irrefutable (Pattern) 
+              | Product (Pos) (Patterns) 
+              | Underscore (Pos) 
+              deriving ( Show)
 -- Patterns ----------------------------------------------------
 {-
    visit 0:
       synthesized attribute:
-         copy                 : SELF
+         copy                 : SELF 
    alternatives:
       alternative Cons:
-         child hd             : Pattern
-         child tl             : Patterns
+         child hd             : Pattern 
+         child tl             : Patterns 
          visit 0:
             local copy        : _
       alternative Nil:
          visit 0:
             local copy        : _
 -}
-type Patterns = [Pattern]
+type Patterns  = [(Pattern)]
\ No newline at end of file
