@@ -1,13 +1,18 @@
--- UUAGC 0.9.5 (SemHsTokens.ag)
+
+
+-- UUAGC 0.9.14 (SemHsTokens.ag)
 module SemHsTokens where
 
-import UU.DData.Seq as Seq(Seq,empty,single,(<>),toList)
+import qualified Data.Sequence as Seq
+import Data.Sequence(Seq,empty,singleton,(><))
+import Data.Foldable(toList)
 import Pretty
 
 import TokenDef
 import HsToken
 import ErrorMessages
 
+
 import CommonTypes
 import UU.Scanner.Position(Pos)
 
@@ -60,40 +65,43 @@ isNTname allnts _                = False
          child pos            : {Pos}
 -}
 -- cata
-sem_HsToken :: HsToken ->
-               T_HsToken
-sem_HsToken (AGField _field _attr _pos _rdesc) =
-    (sem_HsToken_AGField _field _attr _pos _rdesc)
-sem_HsToken (AGLocal _var _pos _rdesc) =
-    (sem_HsToken_AGLocal _var _pos _rdesc)
-sem_HsToken (CharToken _value _pos) =
-    (sem_HsToken_CharToken _value _pos)
-sem_HsToken (Err _mesg _pos) =
-    (sem_HsToken_Err _mesg _pos)
-sem_HsToken (HsToken _value _pos) =
-    (sem_HsToken_HsToken _value _pos)
-sem_HsToken (StrToken _value _pos) =
-    (sem_HsToken_StrToken _value _pos)
+sem_HsToken :: HsToken  ->
+               T_HsToken 
+sem_HsToken (AGField _field _attr _pos _rdesc )  =
+    (sem_HsToken_AGField _field _attr _pos _rdesc )
+sem_HsToken (AGLocal _var _pos _rdesc )  =
+    (sem_HsToken_AGLocal _var _pos _rdesc )
+sem_HsToken (CharToken _value _pos )  =
+    (sem_HsToken_CharToken _value _pos )
+sem_HsToken (Err _mesg _pos )  =
+    (sem_HsToken_Err _mesg _pos )
+sem_HsToken (HsToken _value _pos )  =
+    (sem_HsToken_HsToken _value _pos )
+sem_HsToken (StrToken _value _pos )  =
+    (sem_HsToken_StrToken _value _pos )
 -- semantic domain
-newtype T_HsToken = T_HsToken (([(Identifier,Type,Bool)]) ->
-                               ([Identifier]) ->
-                               ([(Identifier,Identifier)]) ->
-                               Identifier ->
-                               ([Identifier]) ->
-                               Identifier ->
-                               ( (Seq Error),((Pos,String)),([(Identifier,Identifier)]),(Seq Identifier),([Identifier])))
-data Inh_HsToken = Inh_HsToken {allfields_Inh_HsToken :: [(Identifier,Type,Bool)],allnts_Inh_HsToken :: [Identifier],attrs_Inh_HsToken :: [(Identifier,Identifier)],con_Inh_HsToken :: Identifier,fieldnames_Inh_HsToken :: [Identifier],nt_Inh_HsToken :: Identifier}
-data Syn_HsToken = Syn_HsToken {errors_Syn_HsToken :: Seq Error,tok_Syn_HsToken :: (Pos,String),usedAttrs_Syn_HsToken :: [(Identifier,Identifier)],usedFields_Syn_HsToken :: Seq Identifier,usedLocals_Syn_HsToken :: [Identifier]}
-wrap_HsToken (T_HsToken sem) (Inh_HsToken _lhsIallfields _lhsIallnts _lhsIattrs _lhsIcon _lhsIfieldnames _lhsInt) =
+newtype T_HsToken  = T_HsToken (([(Identifier,Type,Bool)]) ->
+                                ([Identifier]) ->
+                                ([(Identifier,Identifier)]) ->
+                                Identifier ->
+                                ([Identifier]) ->
+                                Identifier ->
+                                ( (Seq Error),((Pos,String)),([(Identifier,Identifier)]),(Seq Identifier),([Identifier])))
+data Inh_HsToken  = Inh_HsToken {allfields_Inh_HsToken :: [(Identifier,Type,Bool)],allnts_Inh_HsToken :: [Identifier],attrs_Inh_HsToken :: [(Identifier,Identifier)],con_Inh_HsToken :: Identifier,fieldnames_Inh_HsToken :: [Identifier],nt_Inh_HsToken :: Identifier}
+data Syn_HsToken  = Syn_HsToken {errors_Syn_HsToken :: Seq Error,tok_Syn_HsToken :: (Pos,String),usedAttrs_Syn_HsToken :: [(Identifier,Identifier)],usedFields_Syn_HsToken :: Seq Identifier,usedLocals_Syn_HsToken :: [Identifier]}
+wrap_HsToken :: T_HsToken  ->
+                Inh_HsToken  ->
+                Syn_HsToken 
+wrap_HsToken (T_HsToken sem ) (Inh_HsToken _lhsIallfields _lhsIallnts _lhsIattrs _lhsIcon _lhsIfieldnames _lhsInt )  =
     (let ( _lhsOerrors,_lhsOtok,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals) =
-             (sem _lhsIallfields _lhsIallnts _lhsIattrs _lhsIcon _lhsIfieldnames _lhsInt)
-     in  (Syn_HsToken _lhsOerrors _lhsOtok _lhsOusedAttrs _lhsOusedFields _lhsOusedLocals))
+             (sem _lhsIallfields _lhsIallnts _lhsIattrs _lhsIcon _lhsIfieldnames _lhsInt )
+     in  (Syn_HsToken _lhsOerrors _lhsOtok _lhsOusedAttrs _lhsOusedFields _lhsOusedLocals ))
 sem_HsToken_AGField :: Identifier ->
                        Identifier ->
                        Pos ->
                        (Maybe String) ->
-                       T_HsToken
-sem_HsToken_AGField field_ attr_ pos_ rdesc_ =
+                       T_HsToken 
+sem_HsToken_AGField field_ attr_ pos_ rdesc_  =
     (T_HsToken (\ _lhsIallfields
                   _lhsIallnts
                   _lhsIattrs
@@ -105,36 +113,36 @@ sem_HsToken_AGField field_ attr_ pos_ rdesc_ =
                          _lhsOtok :: ((Pos,String))
                          _lhsOusedFields :: (Seq Identifier)
                          _lhsOusedLocals :: ([Identifier])
-                         -- "SemHsTokens.ag"(line 72, column 15)
+                         -- "SemHsTokens.ag"(line 74, column 15)
                          _lhsOerrors =
                              if (field_,attr_) `elem` _lhsIattrs
                                    then Seq.empty
                                    else if not(field_ `elem` (_LHS : _LOC: _lhsIfieldnames))
-                                           then Seq.single (UndefChild _lhsInt _lhsIcon field_)
-                                           else Seq.single (UndefAttr _lhsInt _lhsIcon field_ attr_ False)
-                         -- "SemHsTokens.ag"(line 86, column 13)
+                                           then Seq.singleton (UndefChild _lhsInt _lhsIcon field_)
+                                           else Seq.singleton (UndefAttr _lhsInt _lhsIcon field_ attr_ False)
+                         -- "SemHsTokens.ag"(line 88, column 13)
                          _lhsOusedAttrs =
                              [(field_,attr_)]
-                         -- "SemHsTokens.ag"(line 113, column 8)
+                         -- "SemHsTokens.ag"(line 115, column 8)
                          _addTrace =
                              case rdesc_ of
                                Just d  -> \x -> "(trace " ++ show (d ++ " -> " ++ show field_ ++ "." ++ show attr_) ++ " (" ++ x ++ "))"
                                Nothing -> id
-                         -- "SemHsTokens.ag"(line 116, column 8)
+                         -- "SemHsTokens.ag"(line 118, column 8)
                          _lhsOtok =
                              (pos_, _addTrace     $ attrname True field_ attr_)
-                         -- use rule "SemHsTokens.ag"(line 91, column 40)
+                         -- use rule "SemHsTokens.ag"(line 93, column 40)
                          _lhsOusedFields =
                              Seq.empty
-                         -- use rule "SemHsTokens.ag"(line 82, column 40)
+                         -- use rule "SemHsTokens.ag"(line 84, column 40)
                          _lhsOusedLocals =
                              []
-                     in  ( _lhsOerrors,_lhsOtok,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals))))
+                     in  ( _lhsOerrors,_lhsOtok,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals))) )
 sem_HsToken_AGLocal :: Identifier ->
                        Pos ->
                        (Maybe String) ->
-                       T_HsToken
-sem_HsToken_AGLocal var_ pos_ rdesc_ =
+                       T_HsToken 
+sem_HsToken_AGLocal var_ pos_ rdesc_  =
     (T_HsToken (\ _lhsIallfields
                   _lhsIallnts
                   _lhsIattrs
@@ -146,46 +154,46 @@ sem_HsToken_AGLocal var_ pos_ rdesc_ =
                          _lhsOusedAttrs :: ([(Identifier,Identifier)])
                          _lhsOusedLocals :: ([Identifier])
                          _lhsOtok :: ((Pos,String))
-                         -- "SemHsTokens.ag"(line 62, column 19)
+                         -- "SemHsTokens.ag"(line 64, column 19)
                          __tup1 =
                              if var_ `elem` _lhsIfieldnames
                              then if  isNTname _lhsIallnts (lookup var_ (map (\(n,t,_) -> (n,t)) _lhsIallfields))
-                                  then (Seq.single(ChildAsLocal _lhsInt _lhsIcon var_), (pos_,fieldname var_), []    )
+                                  then (Seq.singleton(ChildAsLocal _lhsInt _lhsIcon var_), (pos_,fieldname var_), []    )
                                   else (Seq.empty, (pos_,fieldname var_), []    )
                              else if (_LOC,var_) `elem` _lhsIattrs
                              then (Seq.empty                                   , (pos_,locname   var_), [var_])
-                             else (Seq.single(UndefLocal _lhsInt _lhsIcon var_), (pos_,locname   var_), []    )
-                         -- "SemHsTokens.ag"(line 62, column 19)
+                             else (Seq.singleton(UndefLocal _lhsInt _lhsIcon var_), (pos_,locname   var_), []    )
+                         -- "SemHsTokens.ag"(line 64, column 19)
                          (_errors,_,_) =
                              __tup1
-                         -- "SemHsTokens.ag"(line 62, column 19)
+                         -- "SemHsTokens.ag"(line 64, column 19)
                          (_,_tok,_) =
                              __tup1
-                         -- "SemHsTokens.ag"(line 62, column 19)
+                         -- "SemHsTokens.ag"(line 64, column 19)
                          (_,_,_usedLocals) =
                              __tup1
-                         -- "SemHsTokens.ag"(line 94, column 13)
+                         -- "SemHsTokens.ag"(line 96, column 13)
                          _lhsOusedFields =
                              if var_ `elem` _lhsIfieldnames
-                              then Seq.single var_
+                              then Seq.singleton var_
                               else Seq.empty
-                         -- use rule "SemHsTokens.ag"(line 41, column 37)
+                         -- use rule "SemHsTokens.ag"(line 43, column 37)
                          _lhsOerrors =
                              _errors
-                         -- use rule "SemHsTokens.ag"(line 83, column 40)
+                         -- use rule "SemHsTokens.ag"(line 85, column 40)
                          _lhsOusedAttrs =
                              []
-                         -- use rule "SemHsTokens.ag"(line 82, column 40)
+                         -- use rule "SemHsTokens.ag"(line 84, column 40)
                          _lhsOusedLocals =
                              _usedLocals
                          -- copy rule (from local)
                          _lhsOtok =
                              _tok
-                     in  ( _lhsOerrors,_lhsOtok,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals))))
+                     in  ( _lhsOerrors,_lhsOtok,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals))) )
 sem_HsToken_CharToken :: String ->
                          Pos ->
-                         T_HsToken
-sem_HsToken_CharToken value_ pos_ =
+                         T_HsToken 
+sem_HsToken_CharToken value_ pos_  =
     (T_HsToken (\ _lhsIallfields
                   _lhsIallnts
                   _lhsIattrs
@@ -197,29 +205,29 @@ sem_HsToken_CharToken value_ pos_ =
                          _lhsOusedAttrs :: ([(Identifier,Identifier)])
                          _lhsOusedFields :: (Seq Identifier)
                          _lhsOusedLocals :: ([Identifier])
-                         -- "SemHsTokens.ag"(line 120, column 16)
+                         -- "SemHsTokens.ag"(line 122, column 16)
                          _lhsOtok =
                              (pos_, if null value_
                                        then ""
                                        else showCharShort (head value_)
                              )
-                         -- use rule "SemHsTokens.ag"(line 41, column 37)
+                         -- use rule "SemHsTokens.ag"(line 43, column 37)
                          _lhsOerrors =
                              Seq.empty
-                         -- use rule "SemHsTokens.ag"(line 83, column 40)
+                         -- use rule "SemHsTokens.ag"(line 85, column 40)
                          _lhsOusedAttrs =
                              []
-                         -- use rule "SemHsTokens.ag"(line 91, column 40)
+                         -- use rule "SemHsTokens.ag"(line 93, column 40)
                          _lhsOusedFields =
                              Seq.empty
-                         -- use rule "SemHsTokens.ag"(line 82, column 40)
+                         -- use rule "SemHsTokens.ag"(line 84, column 40)
                          _lhsOusedLocals =
                              []
-                     in  ( _lhsOerrors,_lhsOtok,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals))))
+                     in  ( _lhsOerrors,_lhsOtok,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals))) )
 sem_HsToken_Err :: String ->
                    Pos ->
-                   T_HsToken
-sem_HsToken_Err mesg_ pos_ =
+                   T_HsToken 
+sem_HsToken_Err mesg_ pos_  =
     (T_HsToken (\ _lhsIallfields
                   _lhsIallnts
                   _lhsIattrs
@@ -231,27 +239,27 @@ sem_HsToken_Err mesg_ pos_ =
                          _lhsOusedAttrs :: ([(Identifier,Identifier)])
                          _lhsOusedFields :: (Seq Identifier)
                          _lhsOusedLocals :: ([Identifier])
-                         -- "SemHsTokens.ag"(line 48, column 9)
+                         -- "SemHsTokens.ag"(line 50, column 9)
                          _lhsOerrors =
                              let m = text mesg_
-                             in Seq.single (CustomError False pos_ m)
-                         -- "SemHsTokens.ag"(line 126, column 16)
+                             in Seq.singleton (CustomError False pos_ m)
+                         -- "SemHsTokens.ag"(line 128, column 16)
                          _lhsOtok =
                              (pos_, "")
-                         -- use rule "SemHsTokens.ag"(line 83, column 40)
+                         -- use rule "SemHsTokens.ag"(line 85, column 40)
                          _lhsOusedAttrs =
                              []
-                         -- use rule "SemHsTokens.ag"(line 91, column 40)
+                         -- use rule "SemHsTokens.ag"(line 93, column 40)
                          _lhsOusedFields =
                              Seq.empty
-                         -- use rule "SemHsTokens.ag"(line 82, column 40)
+                         -- use rule "SemHsTokens.ag"(line 84, column 40)
                          _lhsOusedLocals =
                              []
-                     in  ( _lhsOerrors,_lhsOtok,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals))))
+                     in  ( _lhsOerrors,_lhsOtok,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals))) )
 sem_HsToken_HsToken :: String ->
                        Pos ->
-                       T_HsToken
-sem_HsToken_HsToken value_ pos_ =
+                       T_HsToken 
+sem_HsToken_HsToken value_ pos_  =
     (T_HsToken (\ _lhsIallfields
                   _lhsIallnts
                   _lhsIattrs
@@ -263,26 +271,26 @@ sem_HsToken_HsToken value_ pos_ =
                          _lhsOusedAttrs :: ([(Identifier,Identifier)])
                          _lhsOusedFields :: (Seq Identifier)
                          _lhsOusedLocals :: ([Identifier])
-                         -- "SemHsTokens.ag"(line 118, column 14)
+                         -- "SemHsTokens.ag"(line 120, column 14)
                          _lhsOtok =
                              (pos_, value_)
-                         -- use rule "SemHsTokens.ag"(line 41, column 37)
+                         -- use rule "SemHsTokens.ag"(line 43, column 37)
                          _lhsOerrors =
                              Seq.empty
-                         -- use rule "SemHsTokens.ag"(line 83, column 40)
+                         -- use rule "SemHsTokens.ag"(line 85, column 40)
                          _lhsOusedAttrs =
                              []
-                         -- use rule "SemHsTokens.ag"(line 91, column 40)
+                         -- use rule "SemHsTokens.ag"(line 93, column 40)
                          _lhsOusedFields =
                              Seq.empty
-                         -- use rule "SemHsTokens.ag"(line 82, column 40)
+                         -- use rule "SemHsTokens.ag"(line 84, column 40)
                          _lhsOusedLocals =
                              []
-                     in  ( _lhsOerrors,_lhsOtok,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals))))
+                     in  ( _lhsOerrors,_lhsOtok,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals))) )
 sem_HsToken_StrToken :: String ->
                         Pos ->
-                        T_HsToken
-sem_HsToken_StrToken value_ pos_ =
+                        T_HsToken 
+sem_HsToken_StrToken value_ pos_  =
     (T_HsToken (\ _lhsIallfields
                   _lhsIallnts
                   _lhsIattrs
@@ -294,22 +302,22 @@ sem_HsToken_StrToken value_ pos_ =
                          _lhsOusedAttrs :: ([(Identifier,Identifier)])
                          _lhsOusedFields :: (Seq Identifier)
                          _lhsOusedLocals :: ([Identifier])
-                         -- "SemHsTokens.ag"(line 125, column 16)
+                         -- "SemHsTokens.ag"(line 127, column 16)
                          _lhsOtok =
                              (pos_, showStrShort value_)
-                         -- use rule "SemHsTokens.ag"(line 41, column 37)
+                         -- use rule "SemHsTokens.ag"(line 43, column 37)
                          _lhsOerrors =
                              Seq.empty
-                         -- use rule "SemHsTokens.ag"(line 83, column 40)
+                         -- use rule "SemHsTokens.ag"(line 85, column 40)
                          _lhsOusedAttrs =
                              []
-                         -- use rule "SemHsTokens.ag"(line 91, column 40)
+                         -- use rule "SemHsTokens.ag"(line 93, column 40)
                          _lhsOusedFields =
                              Seq.empty
-                         -- use rule "SemHsTokens.ag"(line 82, column 40)
+                         -- use rule "SemHsTokens.ag"(line 84, column 40)
                          _lhsOusedLocals =
                              []
-                     in  ( _lhsOerrors,_lhsOtok,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals))))
+                     in  ( _lhsOerrors,_lhsOtok,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals))) )
 -- HsTokens ----------------------------------------------------
 {-
    visit 0:
@@ -328,33 +336,36 @@ sem_HsToken_StrToken value_ pos_ =
          usedLocals           : [Identifier]
    alternatives:
       alternative Cons:
-         child hd             : HsToken
-         child tl             : HsTokens
+         child hd             : HsToken 
+         child tl             : HsTokens 
       alternative Nil:
 -}
 -- cata
-sem_HsTokens :: HsTokens ->
-                T_HsTokens
-sem_HsTokens list =
-    (Prelude.foldr sem_HsTokens_Cons sem_HsTokens_Nil (Prelude.map sem_HsToken list))
+sem_HsTokens :: HsTokens  ->
+                T_HsTokens 
+sem_HsTokens list  =
+    (Prelude.foldr sem_HsTokens_Cons sem_HsTokens_Nil (Prelude.map sem_HsToken list) )
 -- semantic domain
-newtype T_HsTokens = T_HsTokens (([(Identifier,Type,Bool)]) ->
-                                 ([Identifier]) ->
-                                 ([(Identifier,Identifier)]) ->
-                                 Identifier ->
-                                 ([Identifier]) ->
-                                 Identifier ->
-                                 ( (Seq Error),([(Pos,String)]),([(Identifier,Identifier)]),(Seq Identifier),([Identifier])))
-data Inh_HsTokens = Inh_HsTokens {allfields_Inh_HsTokens :: [(Identifier,Type,Bool)],allnts_Inh_HsTokens :: [Identifier],attrs_Inh_HsTokens :: [(Identifier,Identifier)],con_Inh_HsTokens :: Identifier,fieldnames_Inh_HsTokens :: [Identifier],nt_Inh_HsTokens :: Identifier}
-data Syn_HsTokens = Syn_HsTokens {errors_Syn_HsTokens :: Seq Error,tks_Syn_HsTokens :: [(Pos,String)],usedAttrs_Syn_HsTokens :: [(Identifier,Identifier)],usedFields_Syn_HsTokens :: Seq Identifier,usedLocals_Syn_HsTokens :: [Identifier]}
-wrap_HsTokens (T_HsTokens sem) (Inh_HsTokens _lhsIallfields _lhsIallnts _lhsIattrs _lhsIcon _lhsIfieldnames _lhsInt) =
+newtype T_HsTokens  = T_HsTokens (([(Identifier,Type,Bool)]) ->
+                                  ([Identifier]) ->
+                                  ([(Identifier,Identifier)]) ->
+                                  Identifier ->
+                                  ([Identifier]) ->
+                                  Identifier ->
+                                  ( (Seq Error),([(Pos,String)]),([(Identifier,Identifier)]),(Seq Identifier),([Identifier])))
+data Inh_HsTokens  = Inh_HsTokens {allfields_Inh_HsTokens :: [(Identifier,Type,Bool)],allnts_Inh_HsTokens :: [Identifier],attrs_Inh_HsTokens :: [(Identifier,Identifier)],con_Inh_HsTokens :: Identifier,fieldnames_Inh_HsTokens :: [Identifier],nt_Inh_HsTokens :: Identifier}
+data Syn_HsTokens  = Syn_HsTokens {errors_Syn_HsTokens :: Seq Error,tks_Syn_HsTokens :: [(Pos,String)],usedAttrs_Syn_HsTokens :: [(Identifier,Identifier)],usedFields_Syn_HsTokens :: Seq Identifier,usedLocals_Syn_HsTokens :: [Identifier]}
+wrap_HsTokens :: T_HsTokens  ->
+                 Inh_HsTokens  ->
+                 Syn_HsTokens 
+wrap_HsTokens (T_HsTokens sem ) (Inh_HsTokens _lhsIallfields _lhsIallnts _lhsIattrs _lhsIcon _lhsIfieldnames _lhsInt )  =
     (let ( _lhsOerrors,_lhsOtks,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals) =
-             (sem _lhsIallfields _lhsIallnts _lhsIattrs _lhsIcon _lhsIfieldnames _lhsInt)
-     in  (Syn_HsTokens _lhsOerrors _lhsOtks _lhsOusedAttrs _lhsOusedFields _lhsOusedLocals))
-sem_HsTokens_Cons :: T_HsToken ->
-                     T_HsTokens ->
-                     T_HsTokens
-sem_HsTokens_Cons (T_HsToken hd_) (T_HsTokens tl_) =
+             (sem _lhsIallfields _lhsIallnts _lhsIattrs _lhsIcon _lhsIfieldnames _lhsInt )
+     in  (Syn_HsTokens _lhsOerrors _lhsOtks _lhsOusedAttrs _lhsOusedFields _lhsOusedLocals ))
+sem_HsTokens_Cons :: T_HsToken  ->
+                     T_HsTokens  ->
+                     T_HsTokens 
+sem_HsTokens_Cons (T_HsToken hd_ ) (T_HsTokens tl_ )  =
     (T_HsTokens (\ _lhsIallfields
                    _lhsIallnts
                    _lhsIattrs
@@ -388,19 +399,19 @@ sem_HsTokens_Cons (T_HsToken hd_) (T_HsTokens tl_) =
                           _tlIusedAttrs :: ([(Identifier,Identifier)])
                           _tlIusedFields :: (Seq Identifier)
                           _tlIusedLocals :: ([Identifier])
-                          -- "SemHsTokens.ag"(line 108, column 10)
+                          -- "SemHsTokens.ag"(line 110, column 10)
                           _lhsOtks =
                               _hdItok : _tlItks
-                          -- use rule "SemHsTokens.ag"(line 41, column 37)
+                          -- use rule "SemHsTokens.ag"(line 43, column 37)
                           _lhsOerrors =
-                              _hdIerrors Seq.<> _tlIerrors
-                          -- use rule "SemHsTokens.ag"(line 83, column 40)
+                              _hdIerrors Seq.>< _tlIerrors
+                          -- use rule "SemHsTokens.ag"(line 85, column 40)
                           _lhsOusedAttrs =
                               _hdIusedAttrs ++ _tlIusedAttrs
-                          -- use rule "SemHsTokens.ag"(line 91, column 40)
+                          -- use rule "SemHsTokens.ag"(line 93, column 40)
                           _lhsOusedFields =
-                              _hdIusedFields Seq.<> _tlIusedFields
-                          -- use rule "SemHsTokens.ag"(line 82, column 40)
+                              _hdIusedFields Seq.>< _tlIusedFields
+                          -- use rule "SemHsTokens.ag"(line 84, column 40)
                           _lhsOusedLocals =
                               _hdIusedLocals ++ _tlIusedLocals
                           -- copy rule (down)
@@ -440,11 +451,11 @@ sem_HsTokens_Cons (T_HsToken hd_) (T_HsTokens tl_) =
                           _tlOnt =
                               _lhsInt
                           ( _hdIerrors,_hdItok,_hdIusedAttrs,_hdIusedFields,_hdIusedLocals) =
-                              (hd_ _hdOallfields _hdOallnts _hdOattrs _hdOcon _hdOfieldnames _hdOnt)
+                              (hd_ _hdOallfields _hdOallnts _hdOattrs _hdOcon _hdOfieldnames _hdOnt )
                           ( _tlIerrors,_tlItks,_tlIusedAttrs,_tlIusedFields,_tlIusedLocals) =
-                              (tl_ _tlOallfields _tlOallnts _tlOattrs _tlOcon _tlOfieldnames _tlOnt)
-                      in  ( _lhsOerrors,_lhsOtks,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals))))
-sem_HsTokens_Nil :: T_HsTokens
+                              (tl_ _tlOallfields _tlOallnts _tlOattrs _tlOcon _tlOfieldnames _tlOnt )
+                      in  ( _lhsOerrors,_lhsOtks,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals))) )
+sem_HsTokens_Nil :: T_HsTokens 
 sem_HsTokens_Nil  =
     (T_HsTokens (\ _lhsIallfields
                    _lhsIallnts
@@ -457,22 +468,22 @@ sem_HsTokens_Nil  =
                           _lhsOusedAttrs :: ([(Identifier,Identifier)])
                           _lhsOusedFields :: (Seq Identifier)
                           _lhsOusedLocals :: ([Identifier])
-                          -- "SemHsTokens.ag"(line 109, column 10)
+                          -- "SemHsTokens.ag"(line 111, column 10)
                           _lhsOtks =
                               []
-                          -- use rule "SemHsTokens.ag"(line 41, column 37)
+                          -- use rule "SemHsTokens.ag"(line 43, column 37)
                           _lhsOerrors =
                               Seq.empty
-                          -- use rule "SemHsTokens.ag"(line 83, column 40)
+                          -- use rule "SemHsTokens.ag"(line 85, column 40)
                           _lhsOusedAttrs =
                               []
-                          -- use rule "SemHsTokens.ag"(line 91, column 40)
+                          -- use rule "SemHsTokens.ag"(line 93, column 40)
                           _lhsOusedFields =
                               Seq.empty
-                          -- use rule "SemHsTokens.ag"(line 82, column 40)
+                          -- use rule "SemHsTokens.ag"(line 84, column 40)
                           _lhsOusedLocals =
                               []
-                      in  ( _lhsOerrors,_lhsOtks,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals))))
+                      in  ( _lhsOerrors,_lhsOtks,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals))) )
 -- HsTokensRoot ------------------------------------------------
 {-
    visit 0:
@@ -490,29 +501,32 @@ sem_HsTokens_Nil  =
          usedLocals           : [Identifier]
    alternatives:
       alternative HsTokensRoot:
-         child tokens         : HsTokens
+         child tokens         : HsTokens 
 -}
 -- cata
-sem_HsTokensRoot :: HsTokensRoot ->
-                    T_HsTokensRoot
-sem_HsTokensRoot (HsTokensRoot _tokens) =
-    (sem_HsTokensRoot_HsTokensRoot (sem_HsTokens _tokens))
+sem_HsTokensRoot :: HsTokensRoot  ->
+                    T_HsTokensRoot 
+sem_HsTokensRoot (HsTokensRoot _tokens )  =
+    (sem_HsTokensRoot_HsTokensRoot (sem_HsTokens _tokens ) )
 -- semantic domain
-newtype T_HsTokensRoot = T_HsTokensRoot (([(Identifier,Type,Bool)]) ->
-                                         ([Identifier]) ->
-                                         ([(Identifier,Identifier)]) ->
-                                         Identifier ->
-                                         Identifier ->
-                                         ( (Seq Error),([String]),([(Identifier,Identifier)]),([Identifier]),([Identifier])))
-data Inh_HsTokensRoot = Inh_HsTokensRoot {allfields_Inh_HsTokensRoot :: [(Identifier,Type,Bool)],allnts_Inh_HsTokensRoot :: [Identifier],attrs_Inh_HsTokensRoot :: [(Identifier,Identifier)],con_Inh_HsTokensRoot :: Identifier,nt_Inh_HsTokensRoot :: Identifier}
-data Syn_HsTokensRoot = Syn_HsTokensRoot {errors_Syn_HsTokensRoot :: Seq Error,textLines_Syn_HsTokensRoot :: [String],usedAttrs_Syn_HsTokensRoot :: [(Identifier,Identifier)],usedFields_Syn_HsTokensRoot :: [Identifier],usedLocals_Syn_HsTokensRoot :: [Identifier]}
-wrap_HsTokensRoot (T_HsTokensRoot sem) (Inh_HsTokensRoot _lhsIallfields _lhsIallnts _lhsIattrs _lhsIcon _lhsInt) =
+newtype T_HsTokensRoot  = T_HsTokensRoot (([(Identifier,Type,Bool)]) ->
+                                          ([Identifier]) ->
+                                          ([(Identifier,Identifier)]) ->
+                                          Identifier ->
+                                          Identifier ->
+                                          ( (Seq Error),([String]),([(Identifier,Identifier)]),([Identifier]),([Identifier])))
+data Inh_HsTokensRoot  = Inh_HsTokensRoot {allfields_Inh_HsTokensRoot :: [(Identifier,Type,Bool)],allnts_Inh_HsTokensRoot :: [Identifier],attrs_Inh_HsTokensRoot :: [(Identifier,Identifier)],con_Inh_HsTokensRoot :: Identifier,nt_Inh_HsTokensRoot :: Identifier}
+data Syn_HsTokensRoot  = Syn_HsTokensRoot {errors_Syn_HsTokensRoot :: Seq Error,textLines_Syn_HsTokensRoot :: [String],usedAttrs_Syn_HsTokensRoot :: [(Identifier,Identifier)],usedFields_Syn_HsTokensRoot :: [Identifier],usedLocals_Syn_HsTokensRoot :: [Identifier]}
+wrap_HsTokensRoot :: T_HsTokensRoot  ->
+                     Inh_HsTokensRoot  ->
+                     Syn_HsTokensRoot 
+wrap_HsTokensRoot (T_HsTokensRoot sem ) (Inh_HsTokensRoot _lhsIallfields _lhsIallnts _lhsIattrs _lhsIcon _lhsInt )  =
     (let ( _lhsOerrors,_lhsOtextLines,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals) =
-             (sem _lhsIallfields _lhsIallnts _lhsIattrs _lhsIcon _lhsInt)
-     in  (Syn_HsTokensRoot _lhsOerrors _lhsOtextLines _lhsOusedAttrs _lhsOusedFields _lhsOusedLocals))
-sem_HsTokensRoot_HsTokensRoot :: T_HsTokens ->
-                                 T_HsTokensRoot
-sem_HsTokensRoot_HsTokensRoot (T_HsTokens tokens_) =
+             (sem _lhsIallfields _lhsIallnts _lhsIattrs _lhsIcon _lhsInt )
+     in  (Syn_HsTokensRoot _lhsOerrors _lhsOtextLines _lhsOusedAttrs _lhsOusedFields _lhsOusedLocals ))
+sem_HsTokensRoot_HsTokensRoot :: T_HsTokens  ->
+                                 T_HsTokensRoot 
+sem_HsTokensRoot_HsTokensRoot (T_HsTokens tokens_ )  =
     (T_HsTokensRoot (\ _lhsIallfields
                        _lhsIallnts
                        _lhsIattrs
@@ -534,16 +548,16 @@ sem_HsTokensRoot_HsTokensRoot (T_HsTokens tokens_) =
                               _tokensIusedAttrs :: ([(Identifier,Identifier)])
                               _tokensIusedFields :: (Seq Identifier)
                               _tokensIusedLocals :: ([Identifier])
-                              -- "SemHsTokens.ag"(line 36, column 18)
+                              -- "SemHsTokens.ag"(line 38, column 18)
                               _tokensOfieldnames =
                                   map (\(n,_,_) -> n) _lhsIallfields
-                              -- "SemHsTokens.ag"(line 98, column 18)
+                              -- "SemHsTokens.ag"(line 100, column 18)
                               _lhsOusedFields =
-                                  Seq.toList _tokensIusedFields
-                              -- "SemHsTokens.ag"(line 105, column 18)
+                                  toList _tokensIusedFields
+                              -- "SemHsTokens.ag"(line 107, column 18)
                               _lhsOtextLines =
                                   showTokens _tokensItks
-                              -- use rule "SemHsTokens.ag"(line 16, column 18)
+                              -- use rule "SemHsTokens.ag"(line 18, column 18)
                               _lhsOerrors =
                                   _tokensIerrors
                               -- copy rule (up)
@@ -568,5 +582,5 @@ sem_HsTokensRoot_HsTokensRoot (T_HsTokens tokens_) =
                               _tokensOnt =
                                   _lhsInt
                               ( _tokensIerrors,_tokensItks,_tokensIusedAttrs,_tokensIusedFields,_tokensIusedLocals) =
-                                  (tokens_ _tokensOallfields _tokensOallnts _tokensOattrs _tokensOcon _tokensOfieldnames _tokensOnt)
-                          in  ( _lhsOerrors,_lhsOtextLines,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals))))
+                                  (tokens_ _tokensOallfields _tokensOallnts _tokensOattrs _tokensOcon _tokensOfieldnames _tokensOnt )
+                          in  ( _lhsOerrors,_lhsOtextLines,_lhsOusedAttrs,_lhsOusedFields,_lhsOusedLocals))) )
\ No newline at end of file
