@@ -1,5 +1,6 @@
 
--- UUAGC 0.9.5 (VisagePatterns.ag)
+
+-- UUAGC 0.9.14 (VisagePatterns.ag)
 module VisagePatterns where
 
 import UU.Scanner.Position(Pos)
@@ -23,11 +24,11 @@ import CommonTypes
          child field          : {Identifier}
          child attr           : {Identifier}
 -}
-data VisagePattern = VAlias (Identifier) (Identifier) (VisagePattern) 
-                   | VConstr (ConstructorIdent) (VisagePatterns) 
-                   | VProduct (Pos) (VisagePatterns) 
-                   | VUnderscore (Pos) 
-                   | VVar (Identifier) (Identifier) 
+data VisagePattern  = VAlias (Identifier) (Identifier) (VisagePattern) 
+                    | VConstr (ConstructorIdent) (VisagePatterns) 
+                    | VProduct (Pos) (VisagePatterns) 
+                    | VUnderscore (Pos) 
+                    | VVar (Identifier) (Identifier) 
 -- VisagePatterns ----------------------------------------------
 {-
    alternatives:
@@ -36,4 +37,4 @@ data VisagePattern = VAlias (Identifier) (Identifier) (VisagePattern)
          child tl             : VisagePatterns 
       alternative Nil:
 -}
-type VisagePatterns = [VisagePattern]
\ No newline at end of file
+type VisagePatterns  = [(VisagePattern)]
\ No newline at end of file
