@@ -8,9 +8,15 @@ import Data.Set(Set)
 import qualified Data.Set as Set
 
 
-type Blocks = Map String [([String], Pos)]
+type Blocks = Map BlockInfo [([String], Pos)]
+type BlockInfo = (BlockType, Maybe NontermIdent)
+data BlockType
+  = BlockImport
+  | BlockPragma
+  | BlockOther
+  deriving (Eq, Ord, Show)
 
-data Identifier  = Ident {getName::String , getPos::Pos}
+data Identifier = Ident { getName::String, getPos::Pos }
 
 instance Eq Identifier where
  Ident x _ == Ident y _ = x == y
@@ -30,11 +36,17 @@ data Type = Haskell String
 data ComplexType = List Type
                  | Tuple [(Identifier, Type)]
                  | Maybe Type
+                 | Either Type Type
+                 | Map Type Type
+                 | IntMap Type
 
 instance Show ComplexType where
-  show (List  t ) = "[" ++ show t ++ "]"
-  show (Tuple ts) = "(" ++ showList [ show n ++ ": " ++ show t | (n,t) <- ts ] "" ++ ")"
-  show (Maybe t ) = "Maybe " ++ show t
+  show (List  t )     = "[" ++ show t ++ "]"
+  show (Tuple ts)     = "(" ++ showList [ show n ++ ": " ++ show t | (n,t) <- ts ] "" ++ ")"
+  show (Maybe t )     = "Maybe " ++ show t
+  show (Either t1 t2) = "Either " ++ show t1 ++ " " ++ show t2
+  show (Map t1 t2)    = "Map " ++ show t1 ++ " " ++ show t2
+  show (IntMap t1)    = "IntMap " ++ show t1
 
 instance Show Type where
   show = typeToHaskellString Nothing []
@@ -46,6 +58,7 @@ type AttrNames   = [(Identifier,Type,(String,String,String))]
 type UseMap      = Map NontermIdent (Map Identifier (String,String,String))
 type PragmaMap   = Map NontermIdent (Map ConstructorIdent (Set Identifier))
 type AttrMap     = Map NontermIdent (Map ConstructorIdent (Set (Identifier,Identifier)))
+type UniqueMap   = Map NontermIdent (Map ConstructorIdent (Map Identifier Identifier))
 type Fields      = [(Identifier,Type)]
 type Derivings   = Map NontermIdent (Set Identifier)
 type ClassContext = [(Identifier, [String])]
@@ -68,8 +81,8 @@ _LOC   = identifier "loc"
 _INST  = identifier "inst"
 _INST' = identifier "inst'"
 _FIELD = identifier "field"
-_FIRST = identifier "first"
-_LAST  = identifier "last"
+_FIRST = identifier "first__"
+_LAST  = identifier "last__"
 
 sdtype :: NontermIdent -> String
 sdtype nt = "T_"++getName nt
@@ -136,8 +149,9 @@ isSELFNonterminal :: Type -> Bool
 isSELFNonterminal (NT nt _) | nt == _SELF = True
 isSELFNonterminal _                       = False
 
+-- TODO: check if the name needs to be converted if the name is T_
 extractNonterminal :: Type -> NontermIdent
-extractNonterminal (NT n _) = n
+extractNonterminal (NT n _) = maybe n id (deforestedNt n)
 
 nontermArgs :: Type -> [String]
 nontermArgs tp
@@ -145,3 +159,7 @@ nontermArgs tp
       NT _ args -> args
       _         -> [] 
 
+deforestedNt :: Identifier -> Maybe Identifier
+deforestedNt nm
+  | take 2 (getName nm) == "T_" = Just (Ident (drop 2 (getName nm)) (getPos nm))
+  | otherwise = Nothing
