@@ -1,4 +1,4 @@
-module Parser --(parseAG)
+module Parser
 where
 import Data.Maybe
 import UU.Parsing
@@ -21,6 +21,7 @@ import UU.Scanner.Position
 import UU.Scanner.TokenShow()
 import System.Directory
 import HsTokenScanner
+import Options
 
 
 type AGParser = AnaParser Input  Pair Token Pos
@@ -30,29 +31,29 @@ pIdentifierU = uncurry Ident <$> pConidPos
 pIdentifier   = uncurry Ident <$> pVaridPos
 
 
-parseAG :: [FilePath] -> String -> IO (AG,[Message Token Pos])
-parseAG  searchPath file 
-              = do (es,_,_,mesg) <- parseFile searchPath file
+parseAG :: Options -> [FilePath] -> String -> IO (AG,[Message Token Pos])
+parseAG opts searchPath file 
+              = do (es,_,_,mesg) <- parseFile opts searchPath file
                    return (AG es, mesg)
 
-depsAG :: [FilePath] -> String -> IO ([String], [Message Token Pos])
-depsAG searchPath file
-  = do (_,_,fs,mesgs) <- parseFile searchPath file
+depsAG :: Options -> [FilePath] -> String -> IO ([String], [Message Token Pos])
+depsAG opts searchPath file
+  = do (_,_,fs,mesgs) <- parseFile opts searchPath file
        return (fs, mesgs)
 
-parseFile :: [FilePath] -> String -> IO  ([Elem],[String],[String],[Message Token Pos ])
-parseFile searchPath file 
+parseFile :: Options -> [FilePath] -> String -> IO  ([Elem],[String],[String],[Message Token Pos ])
+parseFile opts searchPath file 
                = do txt <- readFile file
                     let litMode = ".lag" `isSuffixOf` file
                         (files,text) = if litMode then scanLit txt
                                        else ([],txt)
-                        tokens       = input (initPos file) text
+                        tokens       = input opts (initPos file) text
 
-                        steps = parse pElemsFiles tokens
+                        steps = parse (pElemsFiles opts) tokens
                         stop (_,fs,_,_) = null fs
                         cont (es,fs,allfs,msg)
                           = do files <- mapM (resolveFile searchPath) fs
-                               res <- mapM (parseFile searchPath) files
+                               res <- mapM (parseFile opts searchPath) files
                                let (ess,fss,allfss, msgs) = unzip4 res
                                return (es ++ concat ess, concat fss, concat allfss ++ allfs, msg ++ concat msgs)
                     let (Pair (es,fls) _ ,mesg) = evalStepsMessages steps
@@ -89,22 +90,23 @@ loopp pred cont x | pred x = return x
                   | otherwise = do x' <- cont x
                                    loopp pred cont x'
                                   
-pElemsFiles :: AGParser ([Elem],[String])
-pElemsFiles = pFoldr (($),([],[])) pElem'
-   where pElem' =  addElem <$> pElem
+pElemsFiles :: Options -> AGParser ([Elem],[String])
+pElemsFiles opts = pFoldr (($),([],[])) pElem'
+   where pElem' =  addElem <$> pElem opts
                <|> pINCLUDE *> (addInc <$> pStringPos)
          addElem e      (es,fs) = (e:es,   fs)
          addInc  (fn,_) (es,fs) = (  es,fn:fs)
 
-pCodescrapL = (\(ValToken _ str pos) -> (str, pos))<$>
-            parseScrapL  <?> "a code block"
+pCodescrapL opts = (\(ValToken _ str pos) -> (str, pos))<$>
+            parseScrapL opts  <?> "a code block"
 
-parseScrapL :: AGParser Token
-parseScrapL = let p acc =  (\k (Input pos str next) ->
+parseScrapL :: Options -> AGParser Token
+parseScrapL opts
+            = let p acc =  (\k (Input pos str next) ->
                             let (sc,rest) = case next of
                                   Just (t@(ValToken TkTextln _ _), rs) -> (t,rs)
                                   _ -> let (tok,p2,inp2) = codescrapL pos str
-                                       in (tok, input p2 inp2)
+                                       in (tok, input opts p2 inp2)
                                 steps   = k ( rest)
                             in  (val (acc sc)  steps)
                        )
@@ -133,42 +135,46 @@ pNontSet = set0
 pNames :: AGParser [Identifier]
 pNames = pList1 pIdentifier
 
-pAG  :: AGParser AG
-pAG  = AG <$> pElems
+-- pAG  :: Options -> AGParser AG
+-- pAG opts = AG <$> pElems opts
 
-pElems :: AGParser Elems
-pElems = pList_ng pElem
+pElems :: Options -> AGParser Elems
+pElems opts = pList_ng (pElem opts)
 
-pComplexType =  List <$> pBracks pTypeEncapsulated 
-            <|> Maybe <$ pMAYBE <*> pType
-            <|> tuple <$> pParens (pListSep pComma field)
- where field = (,) <$> ((Just <$> pIdentifier <* pColon) `opt` Nothing) <*> pTypeEncapsulated
+pComplexType opts =  List   <$> pBracks pTypeEncapsulated 
+            <|> Maybe  <$ pMAYBE <*> pType
+            <|> Either <$ pEITHER <*> pType <*> pType
+            <|> Map    <$ pMAP <*> pTypePrimitive <*> pType
+            <|> IntMap <$ pINTMAP <*> pType
+            <|> tuple  <$> pParens (pListSep pComma field)
+ where field = (,) <$> ((Just <$> pIdentifier <* pTypeColon opts) `opt` Nothing) <*> pTypeEncapsulated
        tuple xs = Tuple [(fromMaybe (Ident ("x"++show n) noPos) f, t) 
                         | (n,(f,t)) <- zip [1..] xs
                         ]
-pElem :: AGParser Elem
-pElem =  Data <$> pDATA
+pElem :: Options -> AGParser Elem
+pElem opts
+      =  Data <$> pDATA
               <*> pOptClassContext
               <*> pNontSet
               <*> pList pIdentifier
-              <*> pOptAttrs
-              <*> pAlts
+              <*> pOptAttrs opts
+              <*> pAlts opts
              <*> pSucceed False
      <|> Attr <$> pATTR
               <*> pOptClassContext
               <*> pNontSet
-              <*> pAttrs
+              <*> pAttrs opts
      <|> Type <$> pTYPE
               <*> pOptClassContext
               <*> pIdentifierU
               <*> pList pIdentifier
               <*  pEquals
-              <*> pComplexType
+              <*> pComplexType opts
      <|> Sem  <$> pSEM
               <*> pOptClassContext
               <*> pNontSet
-              <*> pOptAttrs
-              <*> pSemAlts
+              <*> pOptAttrs opts
+              <*> pSemAlts opts
      <|> Set  <$> pSET
               <*> pIdentifierU
               <*  pEquals
@@ -189,8 +195,8 @@ pElem =  Data <$> pDATA
               <*> pCodescrap'
               <*> pCodescrap'
               <*> pCodescrap'
-     <|> codeBlock <$> (pIdentifier <|> pSucceed (Ident "" noPos)) <*> pCodeBlock <?> "a statement"
-           where codeBlock nm (txt,pos) = Txt pos nm (lines txt)
+     <|> codeBlock <$> (pIdentifier <|> pSucceed (Ident "" noPos)) <*> ((Just <$ pATTACH <*> pIdentifierU) <|> pSucceed Nothing) <*> pCodeBlock <?> "a statement"
+           where codeBlock nm mbNt (txt,pos) = Txt pos nm mbNt (lines txt)
 
 
 -- Insertion is expensive for pCodeBlock in order to prevent infinite inserts.
@@ -207,19 +213,34 @@ pClassContext :: AGParser ClassContext
 pClassContext
   = pListSep pComma ((,) <$> pIdentifierU <*> pList pTypeHaskellAnyAsString)
 
-pAttrs :: AGParser Attrs
-pAttrs = Attrs <$> pOBrackPos <*> (concat <$> pList pInhAttrNames <?> "inherited attribute declarations")
-                              <* pBar    <*> (concat <$> pList pAttrNames <?> "chained attribute declarations"  )
-                              <* pBar    <*> (concat <$> pList pAttrNames <?> "synthesised attribute declarations"  )
+pAttrs :: Options -> AGParser Attrs
+pAttrs opts
+    = Attrs <$> pOBrackPos <*> (concat <$> pList (pInhAttrNames opts) <?> "inherited attribute declarations")
+                              <* pBar    <*> (concat <$> pList (pAttrNames opts) <?> "chained attribute declarations"  )
+                              <* pBar    <*> (concat <$> pList (pAttrNames opts) <?> "synthesised attribute declarations"  )
                <*  pCBrack
+       <|> (\ds -> Attrs (fst $ head ds) [n | (_,Left nms) <- ds, n <- nms] [] [n | (_,Right nms) <- ds, n <- nms]) <$> pList1 (pSingleAttrDefs opts)
 
-pOptAttrs :: AGParser Attrs
-pOptAttrs = pAttrs `opt` Attrs noPos [] [] []
+pSingleAttrDefs :: Options -> AGParser (Pos, Either AttrNames AttrNames)
+pSingleAttrDefs opts
+  =    (\p is -> (p, Left is))  <$> pINH <*> pList1Sep pComma (pSingleInhAttrDef opts)
+  <|>  (\p is -> (p, Right is)) <$> pSYN <*> pList1Sep pComma (pSingleSynAttrDef opts)
+
+pSingleInhAttrDef :: Options -> AGParser (Identifier,Type,(String,String,String))
+pSingleInhAttrDef opts
+  = (\v tp -> (v,tp,("","",""))) <$> pIdentifier <* pTypeColon opts <*> pType <?> "inh attribute declaration"
+
+pSingleSynAttrDef :: Options -> AGParser (Identifier,Type,(String,String,String))
+pSingleSynAttrDef opts
+  = (\v u tp -> (v,tp,u)) <$> pIdentifier <*> pUse <* pTypeColon opts <*> pType <?> "syn attribute declaration"
+
+pOptAttrs :: Options -> AGParser Attrs
+pOptAttrs opts = pAttrs opts `opt` Attrs noPos [] [] []
 
 pTypeNt :: AGParser Type
 pTypeNt
-  =   (\nt -> NT nt []) <$> pIdentifierU
-  <|> pParens (NT <$> pIdentifierU <*> pList pTypeHaskellAnyAsString)
+  =   ((\nt -> NT nt []) <$> pIdentifierU <?> "nonterminal name (no brackets)")
+  <|> (pParens (NT <$> pIdentifierU <*> pList pTypeHaskellAnyAsString) <?> "nonterminal name with parameters (using parenthesis)")
 
 pTypeHaskellAnyAsString :: AGParser String
 pTypeHaskellAnyAsString
@@ -233,49 +254,55 @@ pTypeEncapsulated
   =   pParens pTypeEncapsulated
   <|> NT <$> pIdentifierU <*> pList pTypeHaskellAnyAsString
   <|> (Haskell . getName) <$> pIdentifier
-  <|> Haskell <$> pCodescrap'  <?> "a type"
+  <|> pTypePrimitive
+
+pTypePrimitive :: AGParser Type
+pTypePrimitive
+  = Haskell <$> pCodescrap'  <?> "a type"
 
 pType :: AGParser Type
 pType =  pTypeNt
-     <|> Haskell <$> pCodescrap'  <?> "a type"
+     <|> pTypePrimitive
 
 
-pInhAttrNames :: AGParser AttrNames
-pInhAttrNames   = (\vs tp -> map (\v -> (v,tp,("","",""))) vs)
-                  <$> pIdentifiers <*  pColon <*> pType <?> "attribute declarations"
+pInhAttrNames :: Options -> AGParser AttrNames
+pInhAttrNames opts
+               = (\vs tp -> map (\v -> (v,tp,("","",""))) vs)
+                  <$> pIdentifiers <*  pTypeColon opts <*> pType <?> "attribute declarations"
 
 pIdentifiers :: AGParser [Identifier]
 pIdentifiers =  pList1Sep pComma pIdentifier <?> "lowercase identifiers"
 
 
-pAttrNames :: AGParser AttrNames
-pAttrNames = (\vs use tp -> map (\v -> (v,tp,use)) vs)
-             <$> pIdentifiers <*> pUse <* pColon <*> pType <?> "attribute declarations"
+pAttrNames :: Options -> AGParser AttrNames
+pAttrNames opts 
+         = (\vs use tp -> map (\v -> (v,tp,use)) vs)
+             <$> pIdentifiers <*> pUse <* pTypeColon opts <*> pType <?> "attribute declarations"
 
 pUse :: AGParser (String,String,String)
 pUse = (  (\u x y->(x,y,show u)) <$> pUSE <*> pCodescrap'  <*> pCodescrap')` opt` ("","","") <?> "USE declaration"
 
-pAlt :: AGParser Alt
-pAlt =  Alt <$> pBar <*> pSimpleConstructorSet <*> pFields <?> "a datatype alternative"
+pAlt :: Options -> AGParser Alt
+pAlt opts =  Alt <$> pBar <*> pSimpleConstructorSet <*> pFields opts <?> "a datatype alternative"
 
-pAlts :: AGParser Alts
-pAlts =  pList_ng pAlt <?> "datatype alternatives"
+pAlts :: Options -> AGParser Alts
+pAlts opts =  pList_ng (pAlt opts) <?> "datatype alternatives"
 
-pFields    :: AGParser Fields
-pFields    = concat <$> pList_ng pField <?> "fields"
+pFields    :: Options -> AGParser Fields
+pFields opts = concat <$> pList_ng (pField opts) <?> "fields"
 
-pField     :: AGParser Fields
-pField     =  (\nms tp -> map (flip (,) tp) nms)
-           <$> pIdentifiers <* pColon <*> pType
+pField     :: Options -> AGParser Fields
+pField opts
+        =  (\nms tp -> map (flip (,) tp) nms)
+           <$> pIdentifiers <* pTypeColon opts <*> pType
            <|> (\s -> [(Ident (mklower (getName s)) (getPos s) ,NT s [])]) <$> pIdentifierU
 
 mklower :: String -> String
 mklower (x:xs) = toLower x : xs
 mklower []     = []
 
-pSemAlt :: AGParser SemAlt
-pSemAlt  = SemAlt
-          <$> pBar <*> pConstructorSet <*> pSemDefs <?> "SEM alternative"
+pSemAlt :: Options -> AGParser SemAlt
+pSemAlt opts = SemAlt <$> pBar <*> pConstructorSet <*> pSemDefs opts <?> "SEM alternative"
 
 pSimpleConstructorSet :: AGParser ConstructorSet
 pSimpleConstructorSet =  CName <$> pIdentifierU
@@ -289,8 +316,8 @@ pConstructorSet =  pChainl (CDifference <$ pMinus) term2
              <|> CAll  <$  pStar
                
 
-pSemAlts :: AGParser SemAlts
-pSemAlts =  pList pSemAlt <?> "SEM alternatives"
+pSemAlts :: Options -> AGParser SemAlts
+pSemAlts opts =  pList (pSemAlt opts) <?> "SEM alternatives"
 
 pFieldIdentifier :: AGParser Identifier
 pFieldIdentifier =  pIdentifier
@@ -298,19 +325,25 @@ pFieldIdentifier =  pIdentifier
                 <|> Ident "loc"  <$> pLOC
                 <|> Ident "inst" <$> pINST
 
-pSemDef :: AGParser [SemDef]
-pSemDef = (\x fs -> map ($ x) fs)<$> pFieldIdentifier <*> pList1 pAttrDef
-      <|>                            pLOC              *> pList1 pLocDecl
-      <|>                            pINST             *> pList1 pInstDecl
+pSemDef :: Options -> AGParser [SemDef]
+pSemDef opts
+      =   (\x fs -> map ($ x) fs)<$> pFieldIdentifier <*> pList1 (pAttrDef opts)
+      <|>                            pLOC              *> pList1 (pLocDecl opts)
+      <|>                            pINST             *> pList1 (pInstDecl opts)
       <|>  pSEMPRAGMA *> pList1 (SemPragma <$> pNames)
+      <|> (\n e -> [AugmentDef n e]) <$ pAugmentToken <*> pIdentifier <* pAssign <*> pExpr opts
       <|> (\a b -> [AttrOrderBefore a [b]]) <$> pList1 pAttr <* pSmaller <*> pAttr
-      <|> (\pat owrt exp -> [Def (pat ()) exp owrt]) <$> pPattern (const <$> pAttr) <*> pAssign <*> pExpr
- 
+      <|> (\pat owrt exp -> [Def (pat ()) exp owrt]) <$> pPattern (const <$> pAttr) <*> pAssign <*> pExpr opts
+
+pAugmentToken :: AGParser ()
+pAugmentToken = () <$ (pAUGMENT <|> pPlus)
+
 pAttr = (,) <$> pFieldIdentifier <* pDot <*> pIdentifier
  
-pAttrDef :: AGParser (Identifier -> SemDef)
-pAttrDef = (\pat owrt exp fld -> Def (pat fld) exp owrt)
-           <$ pDot <*> pattern <*> pAssign <*> pExpr
+pAttrDef :: Options -> AGParser (Identifier -> SemDef)
+pAttrDef opts
+  = (\pat owrt exp fld -> Def (pat fld) exp owrt)
+           <$ pDot <*> pattern <*> pAssign <*> pExpr opts
   where pattern =  pPattern pVar
                <|> (\ir a fld -> ir $ Alias fld a (Underscore noPos) []) <$> ((Irrefutable <$ pTilde) `opt` id) <*> pIdentifier
 
@@ -320,33 +353,33 @@ nl2sp '\n' = ' '
 nl2sp '\r' = ' '
 nl2sp x = x
 
-pLocDecl :: AGParser SemDef
-pLocDecl =   (\ident tp -> TypeDef ident tp)
-              <$ pDot <*> pIdentifier <* pColon <*> pLocType
+pLocDecl :: Options -> AGParser SemDef
+pLocDecl opts = pDot <**> (pIdentifier <**> (pTypeColon opts <**> (   (\tp _ ident _  -> TypeDef ident tp) <$> pLocType
+                                                                  <|> (\ref _ ident _ -> UniqueDef ident ref) <$ pUNIQUEREF <*> pIdentifier )))
 
 pLocType = (Haskell . getName) <$> pIdentifierU
        <|> Haskell <$> pCodescrap'  <?> "a type"
 
-pInstDecl :: AGParser SemDef
-pInstDecl = (\ident tp -> TypeDef ident tp)
-             <$ pDot <*> pIdentifier <* pColon <*> pTypeNt
+pInstDecl :: Options -> AGParser SemDef
+pInstDecl opts = (\ident tp -> TypeDef ident tp)
+                  <$ pDot <*> pIdentifier <* pTypeColon opts <*> pTypeNt
 
-pSemDefs :: AGParser SemDefs
-pSemDefs =  concat <$> pList_ng pSemDef  <?> "attribute rules"
+pSemDefs :: Options -> AGParser SemDefs
+pSemDefs opts =  concat <$> pList_ng (pSemDef opts) <?> "attribute rules"
 
 pVar :: AGParser (Identifier -> (Identifier, Identifier))
 pVar = (\att fld -> (fld,att)) <$> pIdentifier
 
  
-pExpr :: AGParser Expression
-pExpr = (\(str,pos) ->  Expression pos (lexTokens pos str)) <$> pCodescrapL <?> "an expression"
+pExpr :: Options -> AGParser Expression
+pExpr opts = (\(str,pos) ->  Expression pos (lexTokens pos str)) <$> pCodescrapL opts <?> "an expression"
 
 pAssign :: AGParser Bool
 pAssign =  False <$ pReserved "="
        <|> True  <$ pReserved ":="
        
-pAttrDefs :: AGParser (Identifier -> [SemDef])
-pAttrDefs = (\fs field -> map ($ field) fs) <$> pList1 pAttrDef  <?> "attribute definitions"
+-- pAttrDefs :: Options -> AGParser (Identifier -> [SemDef])
+-- pAttrDefs opts = (\fs field -> map ($ field) fs) <$> pList1 (pAttrDef opts) <?> "attribute definitions"
 
 pPattern :: AGParser (a -> (Identifier,Identifier)) -> AGParser (a -> Pattern)
 pPattern pvar = pPattern2 where
@@ -370,22 +403,36 @@ pCodescrap' = fst <$> pCodescrap
 pCodescrap ::  AGParser (String,Pos)
 pCodescrap   = pCodeBlock
 
+pTypeColon :: Options -> AGParser Pos
+pTypeColon opts
+  = if doubleColons opts
+    then pDoubleColon
+    else pColon
+
+
 pSEM, pATTR, pDATA, pUSE, pLOC,pINCLUDE, pTYPE, pEquals, pColonEquals, pTilde,
       pBar, pColon, pLHS,pINST,pSET,pDERIVING,pMinus,pIntersect,pDoubleArrow,pArrow,
-      pDot, pUScore, pEXT,pAt,pStar, pSmaller, pWRAPPER, pPRAGMA, pMAYBE, pMODULE
+      pDot, pUScore, pEXT,pAt,pStar, pSmaller, pWRAPPER, pPRAGMA, pMAYBE, pEITHER, pMAP, pINTMAP,
+      pMODULE, pATTACH, pUNIQUEREF, pINH, pSYN, pAUGMENT, pPlus
       :: AGParser Pos
 pSET         = pCostReserved 90 "SET"     <?> "SET"
 pDERIVING    = pCostReserved 90 "DERIVING"<?> "DERIVING"
 pWRAPPER     = pCostReserved 90 "WRAPPER" <?> "WRAPPER"
 pPRAGMA      = pCostReserved 90 "PRAGMA"  <?> "PRAGMA"
 pSEMPRAGMA   = pCostReserved 90 "SEMPRAGMA" <?> "SEMPRAGMA"
+pATTACH      = pCostReserved 90 "ATTACH"  <?> "ATTACH"
 pDATA        = pCostReserved 90 "DATA"    <?> "DATA"
 pEXT         = pCostReserved 90 "EXT"     <?> "EXT"
 pATTR        = pCostReserved 90 "ATTR"    <?> "ATTR"
 pSEM         = pCostReserved 90 "SEM"     <?> "SEM"
 pINCLUDE     = pCostReserved 90 "INCLUDE" <?> "INCLUDE"
 pTYPE        = pCostReserved 90 "TYPE"    <?> "TYPE"
+pINH         = pCostReserved 90 "INH"     <?> "INH"
+pSYN         = pCostReserved 90 "SYN"     <?> "SYN"
 pMAYBE       = pCostReserved 5  "MAYBE"   <?> "MAYBE"
+pEITHER      = pCostReserved 5  "EITHER"  <?> "EITHER"
+pMAP         = pCostReserved 5  "MAP"     <?> "MAP"
+pINTMAP      = pCostReserved 5  "INTMAP"  <?> "INTMAP"
 pUSE         = pCostReserved 5  "USE"     <?> "USE"
 pLOC         = pCostReserved 5  "loc"     <?> "loc"
 pLHS         = pCostReserved 5  "lhs"     <?> "loc"
@@ -394,9 +441,11 @@ pAt          = pCostReserved 5  "@"       <?> "@"
 pDot         = pCostReserved 5  "."       <?> "."
 pUScore      = pCostReserved 5  "_"       <?> "_"
 pColon       = pCostReserved 5  ":"       <?> ":"
+pDoubleColon = pCostReserved 5  "::"      <?> "::"
 pEquals      = pCostReserved 5  "="       <?> "="
 pColonEquals = pCostReserved 5  ":="      <?> ":="
 pTilde       = pCostReserved 5  "~"       <?> "~"
+pPlus        = pCostReserved 5  "+"       <?> "+"
 pBar         = pCostReserved 5  "|"       <?> "|"
 pIntersect   = pCostReserved 5  "/\\"     <?> "/\\"
 pMinus       = pCostReserved 5  "-"       <?> "-"
@@ -405,4 +454,5 @@ pArrow       = pCostReserved 5  "->"      <?> "->"
 pStar        = pCostReserved 5  "*"       <?> "*"
 pSmaller     = pCostReserved 5  "<"       <?> "<"
 pMODULE      = pCostReserved 5  "MODULE"  <?> "MODULE"
-
+pUNIQUEREF   = pCostReserved 5  "UNIQUEREF" <?> "UNIQUEREF"
+pAUGMENT     = pCostReserved 5  "AUGMENT" <?> "AUGMENT"
