@@ -1,6 +1,7 @@
-
+{-# OPTIONS -fglasgow-exts #-}
 module TokenDef where
 
+import GHC.Prim
 import UU.Scanner.Token
 import UU.Scanner.GenToken
 import UU.Scanner.GenTokenOrd
@@ -13,17 +14,17 @@ import CommonTypes
 
 
 instance Symbol Token  where
- deleteCost (Reserved key _) = case key of 
-                "DATA"         -> 7
-                "EXT"          -> 7
-                "ATTR"         -> 7
-                "SEM"          -> 7
-                "USE"          -> 7
-                "INCLUDE"      -> 7
-                _              -> 5
+ deleteCost (Reserved key _) = case key of
+                "DATA"         -> 7#
+                "EXT"          -> 7#
+                "ATTR"         -> 7#
+                "SEM"          -> 7#
+                "USE"          -> 7#
+                "INCLUDE"      -> 7#
+                _              -> 5#
  deleteCost (ValToken v _  _) = case v of
-                TkError -> 0
-                _       -> 5
+                TkError -> 0#
+                _       -> 5#
 
 
 tokensToStrings :: [HsToken] -> [(Pos,String)]
